import { CfnOutput, Duration, Stack, StackProps } from 'aws-cdk-lib';
import { ParameterStore, ParameterStoreOptions } from '../../aws-ssm';
import { Construct } from 'constructs';
import { StringParameter } from 'aws-cdk-lib/aws-ssm';
import { DashboardRenderingPreference, MonitoringFacade } from 'cdk-monitoring-constructs';
import { StandardTags, StandardTagsProps } from './standard-tags';
/**
 * Options for ExtStack.
 */
export interface ExtendedStackOptions {
    /**
     * Prefix to be used by parameter exports to be stored in the
     * Systems Manager Parameter Store.
     *
     * @default ${stageName}/${stackId}/Exports/
     */
    readonly parameterExportsPrefix?: string;
    /**
     * Flag to determine if a default MonitoringFacade and
     * DefaultDashboardFactory should be created in this stack.
     *
     * @default true
     */
    readonly createMonitoringFacade?: boolean;
    /**
     * Prefix added to each dashboard name.
     *
     * @default stackName
     */
    readonly dashboardNamePrefix?: string;
    /**
     * Flag to determine if the default dashboard should be created.
     *
     * @default false
     */
    readonly createDashboard?: boolean;
    /**
     * Flag to determine if the summary dashboard should be created.
     *
     * @default false
     */
    readonly createSummaryDashboard?: boolean;
    /**
     * Flag to determine if the alarm dashboard should be created.
     *
     * @default false
     */
    readonly createAlarmDashboard?: boolean;
    /**
     * Rendering preference to dashboards.
     *
     * @default DashboardRenderingPreference.INTERACTIVE_ONLY
     */
    readonly dashboardRenderingPreference?: DashboardRenderingPreference;
    /**
     * Default namespace for metrics.
     */
    readonly metricNamespace?: string;
    /**
     * Default metric period
     */
    readonly metricPeriod?: Duration;
    /**
     * Prefix for generated alarms.
     *
     * @default stackName
     */
    readonly alarmNamePrefix?: string;
    /**
     * Enables alarm actions.
     *
     * @default true
     */
    readonly alarmActionsEnabled?: boolean;
    /**
     * Sets standard tags for this Stack.
     */
    readonly standardTags?: StandardTagsProps;
}
/**
 * Properties for ExtStack.
 */
export interface ExtendedStackProps extends ExtendedStackOptions, StackProps {
}
/**
 * Extended version of Stack providing functionality for parameter exports and monitoring.
 */
export declare class ExtendedStack extends Stack {
    protected readonly parameterExports: ParameterStore;
    readonly parameterExportOptions: ParameterStoreOptions;
    readonly monitoringFacade?: MonitoringFacade;
    readonly standardTags: StandardTags;
    constructor(scope: Construct, id: string, props?: ExtendedStackProps);
    /**
     * Helper method to exports a parameter as an SSM Parameter.
     *
     * @param name the parameter name
     * @param value the parameter value
     */
    exportParameter(name: string, value: string): StringParameter;
    /**
     * Helper method to output a parameter as a CfnOutput.
     *
     * @param name the parameter name
     * @param value the parameter value
     */
    outputParameter(name: string, value: string): CfnOutput;
}
