import { Construct } from 'constructs';
import { TagProps, Tags } from 'aws-cdk-lib';
export declare const EXCLUDED_RESOURCES: string[];
/**
 * Properties for automation component tags.
 * You may exclude resources for all standard tags using the inherited property excludeResourceTypes.
 */
export interface AutomationComponentTagsProps extends TagProps {
    /**
     * The ID of the component.
     */
    readonly id?: string;
    /**
     * The URL of the component.
     */
    readonly url?: string;
    /**
     * The vendor of the component.
     */
    readonly vendor?: string;
}
/**
 * Properties for automation tags.
 * You may exclude resources using the inherited property excludeResourceTypes.
 */
export interface AutomationTagsProps extends TagProps {
    /**
     * The ID of the stack. If one if not provided, the name of the stack is used.
     *
     * @default - Stack.of(this).stackName
     */
    readonly id?: string;
    /**
     * The URL to where the automation is stored or published. This field is required
     * when applying automation tags.
     */
    readonly url?: string;
}
/**
 * Properties for cost center tags.
 * You may exclude resources using the inherited property excludeResourceTypes.
 */
export interface CostCenterTagsProps extends TagProps {
    /**
     * Name of the project responsible for creating the costs.
     */
    readonly projectName?: string;
    /**
     * Identifier for the project responsible for creating the costs.
     */
    readonly projectId?: string;
    /**
     * Name of the environment incurring the costs. Example "stage" or "prod"
     */
    readonly environment?: string;
    /**
     * Name of the contact responsible for costs associated with the tagged resources.
     * If not set, the tag is not created.
     */
    readonly contactName?: string;
    /**
     * Email of the contact responsible for the costs associated with the tagged resources.
     * If not set, the tag is not created.
     */
    readonly contactEmail?: string;
    /**
     * Phone number of the contact responsible for costs associated with the tagged resources.
     * If not set, the tag is not created.
     */
    readonly contactPhone?: string;
    /**
     * Name of the business unit responsible for the costs associated with the tagged resources.
     */
    readonly businessUnitName?: string;
    /**
     * Identifier for the business unit responsible for the costs associated with the tagged resources.
     */
    readonly businessUnitId?: string;
    /**
     * Name of the business division responsible for the costs associated with the tagged resources.
     */
    readonly divisionName?: string;
    /**
     * Identifier for the business division responsible for the costs associated with the tagged resources.
     */
    readonly divisionId?: string;
    /**
     * Name of the department responsible for the costs associated with the tagged resources.
     */
    readonly departmentName?: string;
    /**
     * Identifier for the department responsible for the costs associated with the tagged resources.
     */
    readonly departmentId?: string;
}
/**
 * Holds values that may be applied to the data-classification security tag.
 */
export declare enum DataClassification {
    /**
     * Used when data may not leave the geographic region in which it is stored.
     * This is usually related to government restrictions applied to the data.
     */
    ExportRestricted = "export-restricted",
    /**
     * Used when unauthorized disclosure, alteration or destruction of data would
     * result in a significant risk to the organization. This includes PII, PHI
     * and PCI data.
     */
    Restricted = "restricted",
    /**
     * Used when unauthorized disclosure, alteration or destruction of the data would
     * result in moderate risk. This includes all data that is not in one of the other
     * classifications.
     */
    Controlled = "controlled",
    /**
     * Used when handled or stored data readily available to the public.
     */
    Public = "public"
}
/**
 * Holds values that may be applied to the data-sensitivity security tag.
 */
export declare enum DataSensitivity {
    /**
     * Used when resources are in PCI scope.
     */
    PCI = "pci",
    /**
     * Used when resources handle or store personally identifiable information.
     */
    PII = "pii",
    /**
     * Used when resources handle or store personal health information and are
     * subject to HIPPA rules.
     */
    PHI = "phi",
    /**
     * Used when there is no data sensitivity.
     */
    NONE = "none"
}
/**
 * Properties for security tags.
 * You may exclude resources using the inherited property excludeResourceTypes.
 */
export interface SecurityTagsProps extends TagProps {
    /**
     * Data classification value. See the TrueMark AWS tagging strategy documentation.
     */
    readonly dataClassification?: DataClassification;
    /**
     * Data sensitivity. See the TrueMark AWS tagging strategy documentation.
     */
    readonly dataSensitivity?: DataSensitivity;
}
/**
 * Properties for team tags.
 * You may exclude resources using the inherited property excludeResourceTypes.
 */
export interface TeamTagsProps extends TagProps {
    /**
     * Name of the team.
     */
    readonly name?: string;
    /**
     * Identifier if different than the team name.
     */
    readonly id?: string;
    /**
     * Name of the team lead.
     */
    readonly contactName?: string;
    /**
     * Email of the team lead.
     */
    readonly contactEmail?: string;
    /**
     * Phone number for the team lead.
     */
    readonly contactPhone?: string;
    /**
     * Name of the business unit responsible for the team associated with the tagged resources.
     */
    readonly businessUnitName?: string;
    /**
     * Identifier for the business unit responsible for the team associated with the tagged resources.
     */
    readonly businessUnitId?: string;
    /**
     * Name of the business division responsible for the team associated with the tagged resources.
     */
    readonly divisionName?: string;
    /**
     * Identifier for the business division responsible for the team associated with the tagged resources.
     */
    readonly divisionId?: string;
    /**
     * Name of the department responsible for the team associated with the tagged resources.
     */
    readonly departmentName?: string;
    /**
     * Identifier for the department responsible for the team associated with the tagged resources.
     */
    readonly departmentId?: string;
}
/**
 * Contains standard tagging properties.
 * You may exclude resources using the inherited property excludeResourceTypes.
 */
export interface StandardTagsProps extends TagProps {
    /**
     * Automation component tags.
     */
    readonly automationComponentTags?: AutomationComponentTagsProps;
    /**
     * Automation tags to apply to created resources.
     */
    readonly automationTags?: AutomationTagsProps;
    /**
     * Cost center tags to apply to created resources.
     */
    readonly costCenterTags?: CostCenterTagsProps;
    /**
     * Security tags to apply to created resources.
     */
    readonly securityTags?: SecurityTagsProps;
    /**
     * Team tags to apply to created resources.
     */
    readonly teamTags?: TeamTagsProps;
    /**
     * The map migrated tag value.
     */
    readonly mapMigrated?: string;
    /**
     * Setting this to true will suppress the creation of tags this resource creates.
     * Default value is false.
     *
     * @default - false
     */
    readonly suppressTagging?: boolean;
}
/**
 * Provides convenience methods to tag resources following TrueMark's tagging strategy.
 */
export declare class StandardTags {
    /**
     * The scope being tagged.
     */
    readonly scope: Construct;
    /**
     * The tags.
     */
    readonly tags: Tags;
    /**
     * If tags were suppressed.
     */
    readonly suppressed: boolean;
    /**
     * Creates a new StandardTags instance.
     *
     * @param scope the scope to tag
     * @param props the properties
     */
    constructor(scope: Construct, props?: StandardTagsProps);
    /**
     * Adds automation component tags. These are meant to be used in individual constructs to identify
     * what resources were stood up by specific constructs.
     *
     * @param props optional properties for the tags
     */
    addAutomationComponentTags(props?: AutomationComponentTagsProps): StandardTags;
    /**
     * Adds automation tags.
     *
     * @param props properties for the tags
     */
    addAutomationTags(props?: AutomationTagsProps): StandardTags;
    /**
     * Adds cost center tags.
     *
     * @param props properties for the tags
     */
    addCostCenterTags(props?: CostCenterTagsProps): StandardTags;
    /**
     * Adds security tags.
     *
     * @param props properties for security tags
     */
    addSecurityTags(props?: SecurityTagsProps): StandardTags;
    /**
     * Adds team tags.
     *
     * @param props properties for team tags
     */
    addTeamTags(props?: TeamTagsProps): StandardTags;
    /**
     * Returns a merged StandardTagsProps.
     *
     * @param from properties to source from
     * @param to properties to source to
     */
    static merge(from?: StandardTagsProps, to?: StandardTagsProps): StandardTagsProps;
}
