"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardTags = exports.DataSensitivity = exports.DataClassification = exports.EXCLUDED_RESOURCES = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
exports.EXCLUDED_RESOURCES = [
    // OAM resources do not like : in the tag names. See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-oam-link.html#cfn-oam-link-tags
    'AWS::Oam::Link',
    'AWS::Oam::Sink',
];
/**
 * Holds values that may be applied to the data-classification security tag.
 */
var DataClassification;
(function (DataClassification) {
    /**
     * Used when data may not leave the geographic region in which it is stored.
     * This is usually related to government restrictions applied to the data.
     */
    DataClassification["ExportRestricted"] = "export-restricted";
    /**
     * Used when unauthorized disclosure, alteration or destruction of data would
     * result in a significant risk to the organization. This includes PII, PHI
     * and PCI data.
     */
    DataClassification["Restricted"] = "restricted";
    /**
     * Used when unauthorized disclosure, alteration or destruction of the data would
     * result in moderate risk. This includes all data that is not in one of the other
     * classifications.
     */
    DataClassification["Controlled"] = "controlled";
    /**
     * Used when handled or stored data readily available to the public.
     */
    DataClassification["Public"] = "public";
})(DataClassification || (exports.DataClassification = DataClassification = {}));
/**
 * Holds values that may be applied to the data-sensitivity security tag.
 */
var DataSensitivity;
(function (DataSensitivity) {
    /**
     * Used when resources are in PCI scope.
     */
    DataSensitivity["PCI"] = "pci";
    /**
     * Used when resources handle or store personally identifiable information.
     */
    DataSensitivity["PII"] = "pii";
    /**
     * Used when resources handle or store personal health information and are
     * subject to HIPPA rules.
     */
    DataSensitivity["PHI"] = "phi";
    /**
     * Used when there is no data sensitivity.
     */
    DataSensitivity["NONE"] = "none";
})(DataSensitivity || (exports.DataSensitivity = DataSensitivity = {}));
/**
 * Provides convenience methods to tag resources following TrueMark's tagging strategy.
 */
class StandardTags {
    /**
     * Creates a new StandardTags instance.
     *
     * @param scope the scope to tag
     * @param props the properties
     */
    constructor(scope, props) {
        var _a, _b;
        props = {
            ...props,
            excludeResourceTypes: [
                ...exports.EXCLUDED_RESOURCES,
                ...((_a = props === null || props === void 0 ? void 0 : props.excludeResourceTypes) !== null && _a !== void 0 ? _a : []),
            ],
        };
        this.scope = scope;
        this.tags = aws_cdk_lib_1.Tags.of(scope);
        this.suppressed = (_b = props === null || props === void 0 ? void 0 : props.suppressTagging) !== null && _b !== void 0 ? _b : false;
        const standardTagsProps = StandardTags.merge(scope.node.tryGetContext('standardTags'), props);
        this.addAutomationComponentTags({
            ...props,
            ...standardTagsProps.automationComponentTags,
        });
        this.addAutomationTags({
            ...props,
            ...standardTagsProps.automationTags,
        });
        this.addCostCenterTags({
            ...props,
            ...standardTagsProps.costCenterTags,
        });
        this.addSecurityTags({
            ...props,
            ...standardTagsProps.securityTags,
        });
        this.addTeamTags({
            ...props,
            ...standardTagsProps.teamTags,
        });
        if (standardTagsProps === null || standardTagsProps === void 0 ? void 0 : standardTagsProps.mapMigrated) {
            this.tags.add('map-migrated', standardTagsProps.mapMigrated, props);
        }
    }
    /**
     * Adds automation component tags. These are meant to be used in individual constructs to identify
     * what resources were stood up by specific constructs.
     *
     * @param props optional properties for the tags
     */
    addAutomationComponentTags(props) {
        if (props && !this.suppressed) {
            if (props.id === '{{TMCDK}}') {
                this.tags.add('automation:component-id', this.scope.constructor.name, {
                    ...props,
                    excludeResourceTypes: [''],
                });
                this.tags.add('automation:component-url', 'https://github.com/truemark/cdk', props);
                this.tags.add('automation:component-vendor', 'TrueMark', props);
            }
            else {
                if (props.id) {
                    this.tags.add('automation:component-id', props.id, props);
                }
                if (props.url) {
                    this.tags.add('automation:component-url', props.url, props);
                }
                if (props.vendor) {
                    this.tags.add('automation:component-vendor', props.vendor, props);
                }
            }
        }
        return this;
    }
    /**
     * Adds automation tags.
     *
     * @param props properties for the tags
     */
    addAutomationTags(props) {
        if (!this.suppressed) {
            let id = props === null || props === void 0 ? void 0 : props.id;
            if (!aws_cdk_lib_1.Stage.isStage(this.scope) && !id) {
                id = aws_cdk_lib_1.Stack.of(this.scope).stackName;
            }
            if (id) {
                this.tags.add('automation:id', id, props);
            }
            if (props === null || props === void 0 ? void 0 : props.url) {
                this.tags.add('automation:url', props.url, props);
            }
        }
        return this;
    }
    /**
     * Adds cost center tags.
     *
     * @param props properties for the tags
     */
    addCostCenterTags(props) {
        if (props && !this.suppressed) {
            if (props.projectName) {
                this.tags.add('cost-center:project-name', props.projectName, props);
            }
            if (props.projectId) {
                this.tags.add('cost-center:project-id', props.projectId, props);
            }
            if (props.environment) {
                this.tags.add('cost-center:environment', props.environment, props);
            }
            if (props.contactName) {
                this.tags.add('cost-center:contact-name', props.contactName, props);
            }
            if (props.contactEmail) {
                this.tags.add('cost-center:contact-email', props.contactEmail, props);
            }
            if (props.contactPhone) {
                this.tags.add('cost-center:contact-phone', props.contactPhone, props);
            }
            if (props.businessUnitName) {
                this.tags.add('cost-center:business-unit-name', props.businessUnitName, props);
            }
            if (props.businessUnitId) {
                this.tags.add('cost-center:business-unit-id', props.businessUnitId, props);
            }
            if (props.divisionName) {
                this.tags.add('cost-center:division-name', props.divisionName, props);
            }
            if (props.divisionId) {
                this.tags.add('cost-center:division-id', props.divisionId, props);
            }
            if (props.departmentName) {
                this.tags.add('cost-center:department-name', props.departmentName, props);
            }
            if (props.departmentId) {
                this.tags.add('cost-center:department-id', props.departmentId, props);
            }
        }
        return this;
    }
    /**
     * Adds security tags.
     *
     * @param props properties for security tags
     */
    addSecurityTags(props) {
        if (props && !this.suppressed) {
            if (props.dataClassification) {
                this.tags.add('security:data-classification', props.dataClassification, props);
            }
            if (props.dataSensitivity) {
                this.tags.add('security:data-sensitivity', props.dataSensitivity, props);
            }
        }
        return this;
    }
    /**
     * Adds team tags.
     *
     * @param props properties for team tags
     */
    addTeamTags(props) {
        if (props && !this.suppressed) {
            if (props.name) {
                this.tags.add('team:name', props.name, props);
            }
            if (props.id) {
                this.tags.add('team:id', props.id, props);
            }
            if (props.contactName) {
                this.tags.add('team:contact-name', props.contactName, props);
            }
            if (props.contactEmail) {
                this.tags.add('team:contact-email', props.contactEmail, props);
            }
            if (props.contactPhone) {
                this.tags.add('team:contact-phone', props.contactPhone, props);
            }
            if (props.businessUnitName) {
                this.tags.add('team:business-unit-name', props.businessUnitName, props);
            }
            if (props.businessUnitId) {
                this.tags.add('team:business-unit-id', props.businessUnitId, props);
            }
            if (props.divisionName) {
                this.tags.add('team:division-name', props.divisionName, props);
            }
            if (props.divisionId) {
                this.tags.add('team:division-id', props.divisionId, props);
            }
            if (props.departmentName) {
                this.tags.add('team:department-name', props.departmentName, props);
            }
            if (props.departmentId) {
                this.tags.add('team:department-id', props.departmentId, props);
            }
        }
        return this;
    }
    /**
     * Returns a merged StandardTagsProps.
     *
     * @param from properties to source from
     * @param to properties to source to
     */
    static merge(from, to) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0;
        let automationComponentTags = undefined;
        if ((from === null || from === void 0 ? void 0 : from.automationComponentTags) || (to === null || to === void 0 ? void 0 : to.automationComponentTags)) {
            automationComponentTags = {
                id: (_d = (_b = (_a = to === null || to === void 0 ? void 0 : to.automationComponentTags) === null || _a === void 0 ? void 0 : _a.id) !== null && _b !== void 0 ? _b : (_c = from === null || from === void 0 ? void 0 : from.automationComponentTags) === null || _c === void 0 ? void 0 : _c.id) !== null && _d !== void 0 ? _d : '',
                ...from === null || from === void 0 ? void 0 : from.automationComponentTags,
                ...to === null || to === void 0 ? void 0 : to.automationComponentTags,
            };
        }
        let automationTags = undefined;
        if ((from === null || from === void 0 ? void 0 : from.automationTags) || (to === null || to === void 0 ? void 0 : to.automationTags)) {
            automationTags = {
                id: (_h = (_f = (_e = to === null || to === void 0 ? void 0 : to.automationTags) === null || _e === void 0 ? void 0 : _e.id) !== null && _f !== void 0 ? _f : (_g = from === null || from === void 0 ? void 0 : from.automationTags) === null || _g === void 0 ? void 0 : _g.id) !== null && _h !== void 0 ? _h : '',
                ...from === null || from === void 0 ? void 0 : from.automationTags,
                ...to === null || to === void 0 ? void 0 : to.automationTags,
            };
        }
        let costCenterTags = undefined;
        if ((from === null || from === void 0 ? void 0 : from.costCenterTags) || (to === null || to === void 0 ? void 0 : to.costCenterTags)) {
            costCenterTags = {
                businessUnitName: (_m = (_k = (_j = to === null || to === void 0 ? void 0 : to.costCenterTags) === null || _j === void 0 ? void 0 : _j.businessUnitName) !== null && _k !== void 0 ? _k : (_l = from === null || from === void 0 ? void 0 : from.costCenterTags) === null || _l === void 0 ? void 0 : _l.businessUnitName) !== null && _m !== void 0 ? _m : '',
                projectName: (_r = (_p = (_o = to === null || to === void 0 ? void 0 : to.costCenterTags) === null || _o === void 0 ? void 0 : _o.projectName) !== null && _p !== void 0 ? _p : (_q = from === null || from === void 0 ? void 0 : from.costCenterTags) === null || _q === void 0 ? void 0 : _q.projectName) !== null && _r !== void 0 ? _r : '',
                ...from === null || from === void 0 ? void 0 : from.costCenterTags,
                ...to === null || to === void 0 ? void 0 : to.costCenterTags,
            };
        }
        let securityTags = undefined;
        if ((from === null || from === void 0 ? void 0 : from.securityTags) || (to === null || to === void 0 ? void 0 : to.securityTags)) {
            securityTags = {
                dataClassification: (_v = (_t = (_s = to === null || to === void 0 ? void 0 : to.securityTags) === null || _s === void 0 ? void 0 : _s.dataClassification) !== null && _t !== void 0 ? _t : (_u = from === null || from === void 0 ? void 0 : from.securityTags) === null || _u === void 0 ? void 0 : _u.dataClassification) !== null && _v !== void 0 ? _v : DataClassification.Controlled,
                ...from === null || from === void 0 ? void 0 : from.securityTags,
                ...to === null || to === void 0 ? void 0 : to.securityTags,
            };
        }
        let teamTags = undefined;
        if ((from === null || from === void 0 ? void 0 : from.teamTags) || (to === null || to === void 0 ? void 0 : to.teamTags)) {
            teamTags = {
                name: (_z = (_x = (_w = to === null || to === void 0 ? void 0 : to.teamTags) === null || _w === void 0 ? void 0 : _w.name) !== null && _x !== void 0 ? _x : (_y = from === null || from === void 0 ? void 0 : from.teamTags) === null || _y === void 0 ? void 0 : _y.name) !== null && _z !== void 0 ? _z : '',
                ...from === null || from === void 0 ? void 0 : from.teamTags,
                ...to === null || to === void 0 ? void 0 : to.teamTags,
            };
        }
        return {
            mapMigrated: (_0 = to === null || to === void 0 ? void 0 : to.mapMigrated) !== null && _0 !== void 0 ? _0 : from === null || from === void 0 ? void 0 : from.mapMigrated,
            automationComponentTags,
            automationTags,
            costCenterTags,
            securityTags,
            teamTags,
        };
    }
}
exports.StandardTags = StandardTags;
//# sourceMappingURL=standard-tags.js.map