"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BehaviorBuilder = exports.DEFAULT_FALLBACK_STATUS_CODES = exports.ALL_FALLBACK_STATUS_CODES = void 0;
const aws_cloudfront_1 = require("aws-cdk-lib/aws-cloudfront");
const redirect_function_1 = require("./redirect-function");
const aws_cloudfront_origins_1 = require("aws-cdk-lib/aws-cloudfront-origins");
const standard_api_cache_policy_1 = require("./standard-api-cache-policy");
const standard_api_origin_request_policy_1 = require("./standard-api-origin-request-policy");
const aws_cdk_1 = require("../../aws-cdk");
const helpers_1 = require("../../helpers");
function pathToIdentifier(path) {
    return helpers_1.StringHelper.toPascalCase(path.replace(/\*/g, 'wildcard').replace(/\//g, '-'));
}
exports.ALL_FALLBACK_STATUS_CODES = [
    400, 403, 404, 405, 500, 502, 503, 504,
];
exports.DEFAULT_FALLBACK_STATUS_CODES = [500, 502, 503, 504];
class BehaviorBuilder extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, origin, path) {
        super(scope, (path === undefined || path === '' ? 'Default' : pathToIdentifier(path)) +
            'Behavior');
        this.path = path;
        scope.addBehavior(this, path);
        this.scope = scope;
        this.options = {
            origin,
        };
    }
    fallbackOrigin(fallbackOrigin, fallbackStatusCodes) {
        if (fallbackOrigin) {
            const originGroup = new aws_cloudfront_origins_1.OriginGroup({
                primaryOrigin: this.options.origin,
                fallbackOrigin,
                fallbackStatusCodes: fallbackStatusCodes !== null && fallbackStatusCodes !== void 0 ? fallbackStatusCodes : exports.DEFAULT_FALLBACK_STATUS_CODES,
            });
            this.options = {
                ...this.options,
                origin: originGroup,
            };
        }
        return this;
    }
    allowedMethods(allowedMethods) {
        this.options = {
            ...this.options,
            allowedMethods,
        };
        return this;
    }
    cachedMethods(cachedMethods) {
        this.options = {
            ...this.options,
            cachedMethods,
        };
        return this;
    }
    cachePolicy(cachePolicy) {
        this.options = {
            ...this.options,
            cachePolicy,
        };
        return this;
    }
    compress(compress) {
        this.options = {
            ...this.options,
            compress,
        };
        return this;
    }
    originRequestPolicy(originRequestPolicy) {
        this.options = {
            ...this.options,
            originRequestPolicy,
        };
        return this;
    }
    responseHeadersPolicy(responseHeadersPolicy) {
        this.options = {
            ...this.options,
            responseHeadersPolicy,
        };
        return this;
    }
    smoothStreaming(smoothStreaming) {
        this.options = {
            ...this.options,
            smoothStreaming,
        };
        return this;
    }
    viewerProtocolPolicy(viewerProtocolPolicy) {
        this.options = {
            ...this.options,
            viewerProtocolPolicy,
        };
        return this;
    }
    functionAssociations(functionAssociations) {
        this.options = {
            ...this.options,
            functionAssociations,
        };
        return this;
    }
    viewerRequestFunction(viewerRequestFunction) {
        var _a;
        const functionAssociations = (_a = this.options.functionAssociations) !== null && _a !== void 0 ? _a : [];
        functionAssociations.push({
            function: viewerRequestFunction,
            eventType: aws_cloudfront_1.FunctionEventType.VIEWER_REQUEST,
        });
        this.options = {
            ...this.options,
            functionAssociations,
        };
        return this;
    }
    redirectFunction(props) {
        const redirectFunction = new redirect_function_1.RedirectFunction(this, 'RedirectFunction', props);
        this.viewerRequestFunction(redirectFunction);
        return this;
    }
    viewerResponseFunction(viewerResponseFunction) {
        var _a;
        const functionAssociations = (_a = this.options.functionAssociations) !== null && _a !== void 0 ? _a : [];
        functionAssociations.push({
            function: viewerResponseFunction,
            eventType: aws_cloudfront_1.FunctionEventType.VIEWER_RESPONSE,
        });
        this.options = {
            ...this.options,
            functionAssociations,
        };
        return this;
    }
    edgeLambdas(edgeLambdas) {
        this.options = {
            ...this.options,
            edgeLambdas,
        };
        return this;
    }
    trustedKeyGroups(trustedKeyGroups) {
        this.options = {
            ...this.options,
            trustedKeyGroups,
        };
        return this;
    }
    s3Defaults() {
        return this.originRequestPolicy(aws_cloudfront_1.OriginRequestPolicy.CORS_S3_ORIGIN);
    }
    apiDefaults(additionalHeaders) {
        const cachePolicy = new standard_api_cache_policy_1.StandardApiCachePolicy(this, 'ApiCachePolicy', additionalHeaders);
        const originRequestPolicy = new standard_api_origin_request_policy_1.StandardApiOriginRequestPolicy(this, 'ApiOriginRequestPolicy', additionalHeaders);
        return this.allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_ALL)
            .cachePolicy(cachePolicy)
            .originRequestPolicy(originRequestPolicy);
    }
    buildBehavior() {
        if (this.options.viewerProtocolPolicy === undefined) {
            this.viewerProtocolPolicy(aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS);
        }
        if (this.options.allowedMethods === undefined) {
            this.allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_GET_HEAD_OPTIONS);
        }
        if (this.options.cachedMethods === undefined) {
            this.cachedMethods(aws_cloudfront_1.CachedMethods.CACHE_GET_HEAD_OPTIONS);
        }
        if (this.options.cachePolicy === undefined) {
            this.cachePolicy(aws_cloudfront_1.CachePolicy.CACHING_OPTIMIZED);
        }
        if (this.options.originRequestPolicy === undefined) {
            this.originRequestPolicy(aws_cloudfront_1.OriginRequestPolicy.ALL_VIEWER);
        }
        if (this.options.compress === undefined) {
            this.compress(true);
        }
        return this.options;
    }
    build() {
        return this.scope.build();
    }
    behavior(origin, path) {
        return this.scope.behavior(origin, path);
    }
    behaviorFromBucket(bucket, path) {
        return this.scope.behaviorFromBucket(bucket, path);
    }
    behaviorFromCloudFromBucket(bucket, path) {
        return this.scope.behaviorFromCloudFromBucket(bucket, path);
    }
    behaviorFromDomainName(domainName, path) {
        return this.scope.behaviorFromDomainName(domainName, path);
    }
    toDistribution() {
        return this.scope.toDistribution();
    }
}
exports.BehaviorBuilder = BehaviorBuilder;
//# sourceMappingURL=behavior-builder.js.map