"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DistributionBuilder = void 0;
const aws_cloudfront_1 = require("aws-cdk-lib/aws-cloudfront");
const behavior_builder_1 = require("./behavior-builder");
const aws_cdk_1 = require("../../aws-cdk");
const aws_cloudfront_origins_1 = require("aws-cdk-lib/aws-cloudfront-origins");
class DistributionBuilder extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id) {
        super(scope, id);
        // eslint-disable-next-line  @typescript-eslint/no-explicit-any
        this.props = {};
        this.behaviors = {};
    }
    getBehavior(path) {
        return this.behaviors[path];
    }
    behavior(origin, path) {
        return new behavior_builder_1.BehaviorBuilder(this, origin, path);
    }
    behaviorFromBucket(bucket, path) {
        return new behavior_builder_1.BehaviorBuilder(this, new aws_cloudfront_origins_1.S3Origin(bucket, {
            originAccessIdentity: new aws_cloudfront_1.OriginAccessIdentity(this, `Access${bucket.node.id}`, {
                comment: `S3 bucket ${bucket.bucketName}`,
            }),
        }), path);
    }
    behaviorFromCloudFromBucket(bucket, path) {
        return new behavior_builder_1.BehaviorBuilder(this, bucket.toOrigin(), path);
    }
    behaviorFromDomainName(domainName, path) {
        return new behavior_builder_1.BehaviorBuilder(this, new aws_cloudfront_origins_1.HttpOrigin(domainName.toString()), path);
    }
    addBehavior(builder, path) {
        this.behaviors[path !== null && path !== void 0 ? path : ''] = builder;
        return this;
    }
    certificate(certificate) {
        this.props = {
            ...this.props,
            certificate,
        };
        return this;
    }
    comment(comment) {
        this.props = {
            ...this.props,
            comment,
        };
        return this;
    }
    defaultRootObject(defaultRootObject) {
        this.props = {
            ...this.props,
            defaultRootObject,
        };
        return this;
    }
    domainNames(...domainNames) {
        const domainNameStrs = domainNames.map(domainName => domainName.toString());
        this.props = {
            ...this.props,
            domainNames: domainNameStrs,
        };
        return this;
    }
    domainName(domainName) {
        var _a;
        const domainNames = (_a = this.props.domainNames) !== null && _a !== void 0 ? _a : [];
        domainNames.push(domainName.toString());
        this.props = {
            ...this.props,
            domainNames,
        };
        return this;
    }
    enabled(enabled) {
        this.props = {
            ...this.props,
            enabled,
        };
        return this;
    }
    enableIpv6(enableIpv6) {
        this.props = {
            ...this.props,
            enableIpv6,
        };
        return this;
    }
    enableLogging(enableLogging) {
        this.props = {
            ...this.props,
            enableLogging,
        };
        return this;
    }
    geoRestriction(geoRestriction) {
        this.props = {
            ...this.props,
            geoRestriction,
        };
        return this;
    }
    httpVersion(httpVersion) {
        this.props = {
            ...this.props,
            httpVersion,
        };
        return this;
    }
    logBucket(logBucket) {
        this.props = {
            ...this.props,
            logBucket,
        };
        return this;
    }
    logIncludesCookies(logIncludesCookies) {
        this.props = {
            ...this.props,
            logIncludesCookies,
        };
        return this;
    }
    logFilePrefix(logFilePrefix) {
        this.props = {
            ...this.props,
            logFilePrefix,
        };
        return this;
    }
    priceClass(priceClass) {
        this.props = {
            ...this.props,
            priceClass,
        };
        return this;
    }
    webAclId(webAclId) {
        this.props = {
            ...this.props,
            webAclId,
        };
        return this;
    }
    errorResponses(errorResponses) {
        this.props = {
            ...this.props,
            errorResponses,
        };
        return this;
    }
    errorResponse(errorResponse) {
        var _a;
        const errorResponses = (_a = this.props.errorResponses) !== null && _a !== void 0 ? _a : [];
        errorResponses.push(errorResponse);
        this.props = {
            ...this.props,
            errorResponses,
        };
        return this;
    }
    minimumProtocolVersion(minimumProtocolVersion) {
        this.props = {
            ...this.props,
            minimumProtocolVersion,
        };
        return this;
    }
    sslSupportMethod(sslSupportMethod) {
        this.props = {
            ...this.props,
            sslSupportMethod,
        };
        return this;
    }
    build() {
        if (this.behaviors[''] === undefined) {
            throw new Error('Default behavior with no path is required');
        }
        if (this.props.enableIpv6 === undefined) {
            this.enableIpv6(true);
        }
        if (this.props.httpVersion === undefined) {
            this.httpVersion(aws_cloudfront_1.HttpVersion.HTTP2_AND_3);
        }
        if (this.props.priceClass === undefined) {
            this.priceClass(aws_cloudfront_1.PriceClass.PRICE_CLASS_100);
        }
        if (this.props.minimumProtocolVersion === undefined) {
            this.minimumProtocolVersion(aws_cloudfront_1.SecurityPolicyProtocol.TLS_V1_2_2021);
        }
        const defaultBehavior = this.behaviors[''].buildBehavior();
        const additionalBehaviors = Object.values(this.behaviors)
            .filter(behavior => behavior.path !== undefined)
            .reduce((behaviors, behavior) => {
            var _a;
            behaviors[(_a = behavior.path) !== null && _a !== void 0 ? _a : ''] = behavior.buildBehavior();
            return behaviors;
        }, {});
        return {
            ...this.props,
            defaultBehavior,
            additionalBehaviors,
        };
    }
    toDistribution() {
        return new aws_cloudfront_1.Distribution(this, 'Default', this.build());
    }
}
exports.DistributionBuilder = DistributionBuilder;
//# sourceMappingURL=distribution-builder.js.map