"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogMetricAlarm = void 0;
const aws_cloudwatch_1 = require("aws-cdk-lib/aws-cloudwatch");
const constructs_1 = require("constructs");
const log_metric_filter_1 = require("./log-metric-filter");
const aws_cloudwatch_actions_1 = require("aws-cdk-lib/aws-cloudwatch-actions");
/**
 * CloudWatch alarm that matches patterns on a LogGroup. This class is a higher-level
 * construct than LogMetricAlarm and will create the filter and metric.
 */
class LogMetricAlarm extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b, _c, _d;
        super(scope, id);
        this.filter = new log_metric_filter_1.LogMetricFilter(this, 'Filter', {
            ...props,
        });
        this.metric = this.filter.sumMetric(props.period);
        this.alarm = new aws_cloudwatch_1.Alarm(this, 'Alarm', {
            ...props,
            threshold: (_a = props.threshold) !== null && _a !== void 0 ? _a : 1,
            evaluationPeriods: (_b = props.evaluationPeriods) !== null && _b !== void 0 ? _b : 2,
            datapointsToAlarm: (_c = props.datapointsToAlarm) !== null && _c !== void 0 ? _c : 1,
            treatMissingData: (_d = props.treatMissingData) !== null && _d !== void 0 ? _d : aws_cloudwatch_1.TreatMissingData.IGNORE,
            metric: this.metric,
        });
        this.alarmArn = this.alarm.alarmArn;
        this.alarmName = this.alarm.alarmName;
        this.env = this.alarm.env;
        this.stack = this.alarm.stack;
    }
    /**
     * Notify SNS topics if the alarm fires.
     *
     * @param topics the topics to notify
     */
    addAlarmTopic(...topics) {
        this.alarm.addAlarmAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Notify SNS topics if the alarm returns from breaching a state into an ok state.
     *
     * @param topics the topics to notify
     */
    addOkTopic(...topics) {
        this.alarm.addOkAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Notify SNS topics if there is insufficient data to evaluate the alarm.
     *
     * @param topics the topics to notify
     */
    addInsufficientDataTopic(...topics) {
        this.alarm.addInsufficientDataAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Trigger actions if the alarm fires.
     *
     * @param actions the actions to trigger
     */
    addAlarmAction(...actions) {
        return this.alarm.addAlarmAction(...actions);
    }
    /**
     * Trigger actions if there is insufficient data to evaluate the alarm.
     *
     * @param actions the actions to trigger
     */
    addInsufficientDataAction(...actions) {
        return this.alarm.addInsufficientDataAction(...actions);
    }
    /**
     * Trigger actions if the alarm returns from breaching a state into an ok state.
     *
     * @param actions the actions to trigger
     */
    addOkAction(...actions) {
        return this.alarm.addOkAction(...actions);
    }
    // From IAlarm
    applyRemovalPolicy(policy) {
        this.alarm.applyRemovalPolicy(policy);
    }
    renderAlarmRule() {
        return this.alarm.renderAlarmRule();
    }
}
exports.LogMetricAlarm = LogMetricAlarm;
//# sourceMappingURL=log-metric-alarm.js.map