import { Construct } from 'constructs';
import { PipelineType } from 'aws-cdk-lib/aws-codepipeline';
import { AddStageOpts, CodePipeline, IFileSetProducer, StageDeployment, Wave, WaveOptions } from 'aws-cdk-lib/pipelines';
import { ComputeType, IBuildImage } from 'aws-cdk-lib/aws-codebuild';
import { PipelineNotificationRule } from './pipeline-notification-rule';
import { Stage } from 'aws-cdk-lib';
import { NodePackageManager } from './enums';
import { PolicyStatement } from 'aws-cdk-lib/aws-iam';
import { ISlackChannelConfiguration } from 'aws-cdk-lib/aws-chatbot';
import { ITopic } from 'aws-cdk-lib/aws-sns';
/**
 * Node runtimes supported by CodebBuild
 * See https://docs.aws.amazon.com/codebuild/latest/userguide/available-runtimes.html
 */
export declare enum NodeVersion {
    NODE_16 = "16",
    NODE_18 = "18",
    NODE_20 = "20"
}
/**
 * Go runtimes supported by CodeBuild
 * See https://docs.aws.amazon.com/codebuild/latest/userguide/available-runtimes.html
 */
export declare enum GoVersion {
    GO_1_12 = "1.12",
    GO_1_13 = "1.13",
    GO_1_14 = "1.14",
    GO_1_15 = "1.15",
    GO_1_16 = "1.16",
    GO_1_17 = "1.17",
    GO_1_18 = "1.18",
    GO_1_20 = "1.20",
    GO_1_21 = "1.21"
}
/**
 * Java runtimes supported by CodeBuild
 * See https://docs.aws.amazon.com/codebuild/latest/userguide/available-runtimes.html
 */
export declare enum JavaVersion {
    JAVA_8 = "corretto8",
    JAVA_11 = "corretto11",
    JAVA_16 = "corretto17",
    JAVA_21 = "corretto21"
}
/**
 * Dotnet runtimes supported by CodeBuild
 * See https://docs.aws.amazon.com/codebuild/latest/userguide/available-runtimes.htmldotnet
 */
export declare enum DotnetVersion {
    DOTNET_3_1 = "3.1",
    DOTNET_5_0 = "5.0",
    DOTNET_6_0 = "6.0"
}
export declare enum PythonVersion {
    PYTHON_3_7 = "3.7",
    PYTHON_3_8 = "3.8",
    PYTHON_3_9 = "3.9",
    PYTHON_3_10 = "3.10",
    PYTHON_3_11 = "3.11",
    PYTHON_3_12 = "3.12"
}
/**
 * Properties for CdkPipeline
 */
export interface CdkPipelineProps {
    /**
     * By default, CDK will name the pipeline. Set this to override the name.
     */
    readonly pipelineName?: string;
    readonly pipelineType?: PipelineType;
    /**
     * By default, CDK will create KMS keys for cross account deployments. This
     * can be costly if you have a large number of pipelines. This property
     * allows a common key to be shared across pipelines.
     */
    readonly keyArn: string;
    /**
     * List of account IDs this pipeline will deploy into.
     */
    readonly accountIds?: string[];
    /**
     * Arn of the CodeStar connection used to access the source code repository. If not set, this
     * construct assumes the repository is in AWS CodeCommit.
     */
    readonly connectionArn?: string;
    /**
     * Source code repository.
     */
    readonly repository: string;
    /**
     * Branch to use inside the source code repository.
     */
    readonly branch: string;
    /**
     * Enable or disable self-mutation. Useful for cdk pipeline development.
     *
     * @default true
     */
    readonly selfMutation?: boolean;
    /**
     * Enable docker for the 'synth' step.
     *
     * @default true
     */
    readonly dockerEnabledForSynth?: boolean;
    /**
     * Enable docker for the self-mutate step.
     *
     * @default true
     */
    readonly dockerEnabledForSelfMutation?: boolean;
    /**
     * Type of compute to use for this build. If not set, the default defined in AWS CDK is used.
     */
    readonly computeType?: ComputeType;
    /**
     * The image to use for builds. If none is selected the default defined in AWS CDK is used.
     */
    readonly buildImage?: IBuildImage;
    /**
     * The ARN of the Slack channel configuration to use for notifications. Mutually exclusive with slackChannelConfiguration.
     */
    readonly slackChannelConfigurationArn?: string;
    /**
     * The Slack channel configuration to use for notifications. Mutually exclusive with slackChannelConfigurationArn.
     */
    readonly slackChannelConfiguration?: ISlackChannelConfiguration;
    /**
     * The SNS topic to use for notifications. Mutually exclusive with notificationTopic.
     */
    readonly notificationTopicArn?: string;
    /**
     * The SNS topic to use for notifications. Mutually exclusive with notificationTopicArn.
     */
    readonly notificationTopic?: ITopic;
    /**
     * The list of notification events to receive. Default is PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS.
     * @default PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS
     * @see https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#events-ref-pipeline
     */
    readonly notificationEvents?: string[];
    /**
     * Additional FileSets to put in other directories
     */
    readonly additionalInputs?: Record<string, IFileSetProducer>;
    /**
     * Additional commands to run before install. If you override the commands property, this has no effect.
     */
    readonly preBuildCommands?: string[];
    /**
     * Overrides default commands.
     */
    readonly commands?: string[];
    /**
     * Public assets in multiple CodeBuild projects. Default is false.
     */
    readonly publishAssetsInParallel?: boolean;
    /**
     * Package manager to use when executing CDK.
     *
     * @default NodePackageManager.PNPM
     */
    readonly packageManager?: NodePackageManager;
    /**
     * The directory the CDK project is located in the repo.
     *
     * @default - "."
     */
    readonly cdkDirectory?: string;
    /**
     * Policy statements to add to the role used by synth.
     */
    readonly rolePolicy?: PolicyStatement[];
    /**
     * Grants read access to the provided AWS CodeArtifact domains.
     */
    readonly codeArtifactDomains?: string[];
    /**
     * Grants read access to the provided AWS CodeArtifact repositories.
     */
    readonly codeArtifactRepositories?: string[];
    /**
     * Version of Node to use in the pipeline. Default is NODE_18
     */
    readonly nodeVersion?: NodeVersion | string;
    /**
     * Version of Go to install. Default is none.
     */
    readonly goVersion?: GoVersion | string;
    /**
     * Version of Java to install. Default is none.
     */
    readonly javaVersion?: JavaVersion | string;
    /**
     * Version of Dotnet to install. Default is none.
     */
    readonly dotnetVersion?: DotnetVersion | string;
    /**
     * Version of Python to install. Default is none.
     */
    readonly pythonVersion?: PythonVersion | string;
    /**
     * Additional commands to run during the install phase.
     */
    readonly additionalInstallCommands?: string[];
    /**
     * Whether to clone the CodeCommit repository into the CodeBuild project.
     */
    readonly codeBuildCloneOutput?: boolean;
}
/**
 * An abstraction to ease CDK pipeline creation and configuration.
 */
export declare class CdkPipeline extends Construct {
    readonly pipeline: CodePipeline;
    readonly pipelineNotificationRule?: PipelineNotificationRule;
    constructor(scope: Construct, id: string, props: CdkPipelineProps);
    addStage(stage: Stage, options?: AddStageOpts): StageDeployment;
    addWave(id: string, options?: WaveOptions): Wave;
}
