import { Construct } from 'constructs';
import { Connections, IVpc } from 'aws-cdk-lib/aws-ec2';
import { Cluster, ExecuteCommandConfiguration, ICluster, CloudMapNamespaceOptions } from 'aws-cdk-lib/aws-ecs';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { LogGroup, RetentionDays } from 'aws-cdk-lib/aws-logs';
import { RemovalPolicy, ResourceEnvironment, Stack } from 'aws-cdk-lib';
import { INamespace } from 'aws-cdk-lib/aws-servicediscovery';
import { IAutoScalingGroup } from 'aws-cdk-lib/aws-autoscaling';
import { ExtendedConstruct, ExtendedConstructProps } from '../../aws-cdk';
export interface StandardFargateClusterProps extends ExtendedConstructProps {
    /**
     * The VPC where your ECS instances will be running.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpc?: IVpc;
    /**
     * The ID of the VPC where your ECS instances will be running.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpcId?: string;
    /**
     * The name of the VPC where your ECS instances will be running.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpcName?: string;
    /**
     * The name for the cluster. Best practice is to not set this value.
     */
    readonly clusterName?: string;
    /**
     * If true CloudWatch Container Insights will be enabled for the cluster
     *
     * @default - true
     */
    readonly containerInsights?: boolean;
    /**
     * Whether to enable Fargate Capacity Providers
     *
     * @default - true
     */
    readonly enableFargateCapacityProviders?: boolean;
    /**
     * The service discovery namespace created in this cluster
     * default service discovery namespace later.
     */
    readonly defaultCloudMapNamespace?: CloudMapNamespaceOptions;
    /**
     * Enables or disables the execute command log for the cluster.
     * This is enabled by default and logs to a CloudWatch log group
     * created by this construct.
     *
     * @default - true
     */
    readonly enableExecuteCommandLog?: boolean;
    /**
     * The KMS key to encrypt data between the local client and container.
     */
    readonly kmsKey?: IKey;
    /**
     * The retention period to use for execute command logs.
     *
     * @default RetentionDays.ONE_MONTH
     */
    readonly executeCommandLogRetention?: RetentionDays;
    /**
     * Allows overriding the default executeCommandConfiguration provided in
     * this construct.
     */
    readonly executeCommandConfigurationOverride?: ExecuteCommandConfiguration;
    /**
     * Setting this to true will suppress the creation of default tags on resources
     * created by this construct. Default is false.
     *
     * @default - false
     */
    readonly suppressTagging?: boolean;
}
/**
 * Standard ECS Cluster that sets up Fargate providers and execute command logging.
 */
export declare class StandardFargateCluster extends ExtendedConstruct implements ICluster {
    readonly vpc: IVpc;
    readonly cluster: Cluster;
    readonly logGroup?: LogGroup;
    readonly clusterName: string;
    readonly clusterArn: string;
    readonly connections: Connections;
    readonly hasEc2Capacity: boolean;
    readonly defaultCloudMapNamespace?: INamespace;
    readonly autoscalingGroup?: IAutoScalingGroup;
    readonly executeCommandConfiguration?: ExecuteCommandConfiguration;
    readonly stack: Stack;
    readonly env: ResourceEnvironment;
    protected resolveVpc(scope: StandardFargateCluster, props: StandardFargateClusterProps): IVpc;
    protected resolveLogGroup(scope: StandardFargateCluster, props: StandardFargateClusterProps): LogGroup | undefined;
    protected resolveExecuteCommandConfiguration(scope: StandardFargateCluster, logGroup: LogGroup | undefined, props: StandardFargateClusterProps): ExecuteCommandConfiguration | undefined;
    constructor(scope: Construct, id: string, props: StandardFargateClusterProps);
    applyRemovalPolicy(policy: RemovalPolicy): void;
}
