"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardFargateCluster = void 0;
const aws_ec2_1 = require("aws-cdk-lib/aws-ec2");
const aws_ecs_1 = require("aws-cdk-lib/aws-ecs");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
/**
 * Standard ECS Cluster that sets up Fargate providers and execute command logging.
 */
class StandardFargateCluster extends aws_cdk_1.ExtendedConstruct {
    resolveVpc(scope, props) {
        if (props.vpc === undefined &&
            props.vpcId === undefined &&
            props.vpcName === undefined) {
            throw new Error('One of vpc, vpcId or vpcName is required');
        }
        return props.vpc !== undefined
            ? props.vpc
            : aws_ec2_1.Vpc.fromLookup(this, 'Vpc', {
                vpcId: props.vpcId,
                vpcName: props.vpcName,
            });
    }
    resolveLogGroup(scope, props) {
        var _a;
        if (((_a = props.enableExecuteCommandLog) !== null && _a !== void 0 ? _a : true) &&
            props.executeCommandConfigurationOverride === undefined) {
            return new aws_logs_1.LogGroup(scope, 'ExecuteCommandLogs', {
                encryptionKey: props.kmsKey,
                retention: aws_logs_1.RetentionDays.ONE_MONTH,
                removalPolicy: aws_cdk_lib_1.RemovalPolicy.DESTROY,
            });
        }
        return undefined;
    }
    resolveExecuteCommandConfiguration(scope, logGroup, props) {
        var _a;
        if ((_a = props.enableExecuteCommandLog) !== null && _a !== void 0 ? _a : true) {
            if (props.executeCommandConfigurationOverride !== undefined) {
                return props.executeCommandConfigurationOverride;
            }
            else {
                return {
                    kmsKey: props.kmsKey,
                    logConfiguration: {
                        cloudWatchEncryptionEnabled: true,
                        cloudWatchLogGroup: logGroup,
                    },
                    logging: aws_ecs_1.ExecuteCommandLogging.OVERRIDE,
                };
            }
        }
        return undefined;
    }
    constructor(scope, id, props) {
        var _a, _b;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props.standardTags, truemark_1.LibStandardTags),
        });
        const vpc = this.resolveVpc(this, props);
        const logGroup = this.resolveLogGroup(this, props);
        const executeCommandConfiguration = this.resolveExecuteCommandConfiguration(this, logGroup, props);
        const cluster = new aws_ecs_1.Cluster(this, 'Default', {
            vpc,
            clusterName: props.clusterName,
            containerInsights: (_a = props.containerInsights) !== null && _a !== void 0 ? _a : true,
            enableFargateCapacityProviders: (_b = props.enableFargateCapacityProviders) !== null && _b !== void 0 ? _b : true,
            defaultCloudMapNamespace: props.defaultCloudMapNamespace,
            executeCommandConfiguration,
        });
        this.vpc = vpc;
        this.cluster = cluster;
        this.logGroup = logGroup;
        this.clusterName = this.cluster.clusterName;
        this.clusterArn = this.cluster.clusterArn;
        this.connections = this.cluster.connections;
        this.hasEc2Capacity = this.cluster.hasEc2Capacity;
        this.defaultCloudMapNamespace = this.cluster.defaultCloudMapNamespace;
        this.autoscalingGroup = this.cluster.autoscalingGroup;
        this.executeCommandConfiguration = this.cluster.executeCommandConfiguration;
        this.stack = this.cluster.stack;
        this.env = this.cluster.env;
    }
    applyRemovalPolicy(policy) {
        this.cluster.applyRemovalPolicy(policy);
    }
}
exports.StandardFargateCluster = StandardFargateCluster;
//# sourceMappingURL=standard-fargate-cluster.js.map