"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlarmFacadeSet = exports.AlarmFacade = void 0;
const alarm_helper_1 = require("./alarm-helper");
const standard_alarm_actions_strategy_1 = require("./standard-alarm-actions-strategy");
const alarms_base_1 = require("./alarms-base");
/**
 * Facade to assist in generating a CustomAlarmThreshold instance.
 */
class AlarmFacade {
    constructor(props) {
        this.props = props;
        this.actions = alarm_helper_1.AlarmHelper.combineActions(props.actions, props.topics);
    }
    /**
     * Converts this AlarmFacade into a CustomAlarmThreshold instance
     */
    toCustomAlarmThreshold() {
        var _a, _b;
        const threshold = (_a = this.props.threshold) !== null && _a !== void 0 ? _a : this.props.defaultThreshold;
        if (threshold !== undefined) {
            if ((typeof threshold === 'number' && threshold > -1) ||
                (typeof threshold === 'object' &&
                    threshold.toSeconds() > 0)) {
                return {
                    [this.props.prop]: (_b = this.props.threshold) !== null && _b !== void 0 ? _b : this.props.defaultThreshold,
                    actionsEnabled: true,
                    actionOverride: new standard_alarm_actions_strategy_1.StandardAlarmActionsStrategy({
                        actions: this.actions,
                    }),
                };
            }
        }
        return undefined;
    }
}
exports.AlarmFacade = AlarmFacade;
/**
 * Facade to assist in creating Record instances containing alarms.
 */
class AlarmFacadeSet {
    constructor(props) {
        this.criticalOptions = props.criticalAlarmOptions;
        this.warningOptions = props.warningAlarmOptions;
        this.record = {};
    }
    /**
     * Add an alarm to the record set.
     *
     * @param category category of the alarm
     * @param oprop property from the AlarmsCategoryOptions instance
     * @param tprop property from the CustomAlarmThreshold instance
     * @param defaultThreshold optional default value for the threshold
     */
    addAlarm(category, oprop, tprop, defaultThreshold) {
        const options = category === alarms_base_1.AlarmCategory.Critical
            ? this.criticalOptions
            : this.warningOptions;
        const customAlarmThreshold = new AlarmFacade({
            prop: tprop,
            threshold: options === null || options === void 0 ? void 0 : options[oprop],
            defaultThreshold,
            topics: options === null || options === void 0 ? void 0 : options.notifyTopics,
            actions: options === null || options === void 0 ? void 0 : options.notifyActions,
        }).toCustomAlarmThreshold();
        if (customAlarmThreshold) {
            this.record[category] = customAlarmThreshold;
        }
        return this;
    }
    /**
     * Adds a critical alarm to the record set.
     *
     * @param oprop property from the AlarmsCategoryOptions instance
     * @param tprop property from the CustomAlarmThreshold instance
     * @param defaultThreshold optional default value for the threshold
     */
    addCriticalAlarm(oprop, tprop, defaultThreshold) {
        return this.addAlarm(alarms_base_1.AlarmCategory.Critical, oprop, tprop, defaultThreshold);
    }
    /**
     * Adds a warning alarm to the record set.
     *
     * @param oprop property from the AlarmsCategoryOptions instance
     * @param tprop property from the CustomAlarmThreshold instance
     * @param defaultThreshold optional default value for the threshold
     */
    addWarningAlarm(oprop, tprop, defaultThreshold) {
        return this.addAlarm(alarms_base_1.AlarmCategory.Warning, oprop, tprop, defaultThreshold);
    }
    /**
     * Adds critical and warning alarms to the record set.
     *
     * @param oprop property from the AlarmsCategoryOptions instance
     * @param tprop property from the CustomAlarmThreshold instance
     * @param defaultCriticalThreshold optional default value for the critical threshold
     * @param defaultWarningThreshold optional default value for the warning threshold
     */
    addAlarms(oprop, tprop, defaultCriticalThreshold, defaultWarningThreshold) {
        this.addCriticalAlarm(oprop, tprop, defaultCriticalThreshold);
        this.addWarningAlarm(oprop, tprop, defaultWarningThreshold);
        return this;
    }
    /**
     * Returns the record set if alarms were created and undefined if otherwise.
     */
    toRecord() {
        return Object.keys(this.record).length > 0 ? this.record : undefined;
    }
}
exports.AlarmFacadeSet = AlarmFacadeSet;
//# sourceMappingURL=alarm-facade.js.map