"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainRedirect = exports.RedirectType = void 0;
const aws_certificatemanager_1 = require("aws-cdk-lib/aws-certificatemanager");
const aws_cloudfront_origins_1 = require("aws-cdk-lib/aws-cloudfront-origins");
const aws_cloudfront_1 = require("aws-cdk-lib/aws-cloudfront");
const aws_route53_targets_1 = require("aws-cdk-lib/aws-route53-targets");
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const aws_cdk_1 = require("../../aws-cdk");
const aws_route53_2 = require("../../aws-route53");
const truemark_1 = require("../../truemark");
const aws_cloudfront_2 = require("../../aws-cloudfront");
var RedirectType;
(function (RedirectType) {
    RedirectType[RedirectType["Permanent"] = 301] = "Permanent";
    RedirectType[RedirectType["Temporary"] = 302] = "Temporary";
})(RedirectType || (exports.RedirectType = RedirectType = {}));
/**
 * Creates a CloudFront distribution that redirects an entire domain to a target.
 */
class DomainRedirect extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id, props) {
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props.standardTags, truemark_1.LibStandardTags),
        });
        if (props.domainNames.length < 1) {
            throw new Error('At least one domain name is required');
        }
        const certificate = new aws_certificatemanager_1.Certificate(this, 'Certificate', {
            domainName: props.domainNames[0].toString(),
            subjectAlternativeNames: props.domainNames
                .slice(1)
                .map(d => d.toString()),
            validation: aws_certificatemanager_1.CertificateValidation.fromDnsMultiZone(aws_route53_2.DomainName.toZoneMap(this, props.domainNames)),
        });
        const redirectType = props.type || RedirectType.Permanent;
        const redirectFunction = new aws_cloudfront_1.Function(this, 'RedirectFunction', {
            code: aws_cloudfront_1.FunctionCode.fromInline(`
function handler(event) {
  return {
    statusCode: ${redirectType},
    statusDescription: "${redirectType === RedirectType.Permanent
                ? 'Permanently Moved'
                : 'Temporarily Moved'}",
    headers: {
        "location": { "value": ${props.appendUri
                ? '"' + props.target + '" + event.request.uri'
                : '"' + props.target + '"'}}
    }
  }
}`),
        });
        const origin = new aws_cloudfront_origins_1.HttpOrigin('example.com');
        const distribution = new aws_cloudfront_2.DistributionBuilder(this, 'Distribution')
            .comment(props.comment)
            .domainNames(...props.domainNames.map(d => d.toString()))
            .certificate(certificate)
            .behavior(origin)
            .allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_GET_HEAD)
            .cachedMethods(aws_cloudfront_1.CachedMethods.CACHE_GET_HEAD)
            .compress(true)
            .cachePolicy(aws_cloudfront_1.CachePolicy.CACHING_OPTIMIZED)
            .viewerProtocolPolicy(aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS)
            .originRequestPolicy(aws_cloudfront_1.OriginRequestPolicy.ALL_VIEWER)
            .functionAssociations([
            {
                eventType: aws_cloudfront_1.FunctionEventType.VIEWER_REQUEST,
                function: redirectFunction,
            },
        ])
            .toDistribution();
        const target = new aws_route53_targets_1.CloudFrontTarget(distribution);
        const records = props.domainNames.map(domainName => domainName.createARecord(this, aws_route53_1.RecordTarget.fromAlias(target)));
        this.certificate = certificate;
        this.distribution = distribution;
        this.records = records;
    }
}
exports.DomainRedirect = DomainRedirect;
//# sourceMappingURL=domain-redirect.js.map