import { Construct } from 'constructs';
import { CfnEIP, IMachineImage, InstanceClass, InstanceSize, InstanceType, ISubnet, IVpc, SecurityGroup, Volume } from 'aws-cdk-lib/aws-ec2';
import { Duration, RemovalPolicy, Size } from 'aws-cdk-lib';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { AutoScalingGroup } from 'aws-cdk-lib/aws-autoscaling';
import { ARecord, IHostedZone } from 'aws-cdk-lib/aws-route53';
import { ApplicationListenerRule, ApplicationTargetGroup, IApplicationListener, ListenerCondition } from 'aws-cdk-lib/aws-elasticloadbalancingv2';
/**
 * Properties for WordPressInstance.
 */
export interface WordPressInstanceProps {
    /**
     * Vpc to place the instance in.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpc?: IVpc;
    /**
     * Name of the vpc to place the instance in.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpcName?: string;
    /**
     * ID of the vpc to place the instance in.
     * One of vpc, vpcId or vpcName is required.
     */
    readonly vpcId?: string;
    /**
     * Subnet to place the volume and instance in.
     * One of subnet or subnetId is required.
     */
    readonly subnet?: ISubnet;
    /**
     * ID of subnet to place the volume and instance in.
     * One of subnet or subnetId is required.
     */
    readonly subnetId?: string;
    /**
     * Availability zone to deploy the instance and volume in.
     */
    readonly availabilityZone: string;
    /**
     * Instance type to use of the instance. A t4g.small is used if not provided.
     */
    readonly instanceType?: InstanceType;
    /**
     * Instance class to use.
     *
     * @default - InstanceClass.BURSTABLE4_GRAVITON
     */
    readonly instanceClass?: InstanceClass;
    /**
     * Instance size to use.
     *
     * @default - InstanceSize.SMALL
     */
    readonly instanceSize?: InstanceSize;
    /**
     * Optional instance name.
     */
    readonly instanceName?: string;
    /**
     * Propagate the EC2 instance tags to the EBS volumes.
     *
     * @default - true
     */
    readonly propagateTagsToVolumeOnCreation?: boolean;
    /**
     * OS volume size in Gigabytes.
     *
     * @default - Size.gigabytes(10)
     */
    readonly osVolumeSize?: Size;
    /**
     * Data volume size in Gigabytes.
     *
     * @default - Size.gigabytes(10)
     */
    readonly dataVolumeSize?: Size;
    /**
     * Data volume removal policy.
     *
     * @default - RemovalPolicy.RETAIN
     */
    readonly dataVolumeRemovalPolicy?: RemovalPolicy;
    /**
     * Encryption key to use for volumes.
     */
    readonly encryptionKey?: IKey;
    /**
     * The domain names of the sites to be hosted by this instance.
     * Each provided site will be a separate WordPress installation.
     */
    readonly sites: string[];
    /**
     * Creates an elastic IP for this EC2 instance. Default is true.
     *
     * @default - true
     */
    readonly createEip?: boolean;
    /**
     * Prefix for the DNS record pointing to the elastic IP address for the EC2 instance.
     */
    readonly hostPrefix?: string;
    /**
     * Zone for the DNS record pointing to the elastic IP address for the EC2 instance.
     */
    readonly hostZone?: IHostedZone | string;
    /**
     * The TTL to use on the DNS record pointing to the elastic IP address for the EC2 instance.
     *
     * @default - Duration.seconds(300)
     */
    readonly hostRecordTtl?: Duration;
    /**
     * Creates a target group which can be attached to an application load balancer. Default is false.
     *
     * @default - false
     */
    readonly createTargetGroup?: boolean;
}
export declare const DEFAULT_ARM_IMAGE_SSM_PARAMETER = "/aws/service/canonical/ubuntu/server/jammy/stable/current/arm64/hvm/ebs-gp2/ami-id";
export declare const DEFAULT_AMD64_IMAGE_SSM_PARAMETER = "/aws/service/canonical/ubuntu/server/jammy/stable/current/amd64/hvm/ebs-gp2/ami-id";
/**
 * Creates a new WordPress instance.
 */
export declare class WordPressInstance extends Construct {
    readonly vpc: IVpc;
    readonly subnet: ISubnet;
    readonly instanceType: InstanceType;
    readonly machineImage: IMachineImage;
    readonly eip?: CfnEIP;
    readonly eipARecord?: ARecord;
    readonly targetGroup?: ApplicationTargetGroup;
    readonly volume: Volume;
    readonly securityGroup: SecurityGroup;
    readonly asg: AutoScalingGroup;
    resolveVpc(scope: Construct, props: WordPressInstanceProps): IVpc;
    resolveInstanceType(scope: Construct, props: WordPressInstanceProps): InstanceType;
    resolveSubnet(scope: Construct, props: WordPressInstanceProps): ISubnet;
    resolveMachineImage(instanceType: InstanceType): IMachineImage;
    constructor(scope: Construct, id: string, props: WordPressInstanceProps);
    /**
     * Convenience method to add the created target group as a default target for a load balancer listener.
     *
     * @param listener - the listener to attach the target group to
     */
    addListenerTarget(listener: IApplicationListener): void;
    /**
     * Convenience method to add a rule to a load balancer listener for the created target group.
     *
     * @param listener - this listener to attach the rule to
     * @param priority - the priority of the rule
     * @param conditions - the listener conditions to match
     */
    addListenerRule(listener: IApplicationListener, priority: number, conditions: ListenerCondition[]): ApplicationListenerRule;
}
