"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WordPressInstance = exports.DEFAULT_AMD64_IMAGE_SSM_PARAMETER = exports.DEFAULT_ARM_IMAGE_SSM_PARAMETER = void 0;
const constructs_1 = require("constructs");
const aws_ec2_1 = require("aws-cdk-lib/aws-ec2");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_autoscaling_1 = require("aws-cdk-lib/aws-autoscaling");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const fs = require("fs");
const path = require("path");
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const aws_route53_2 = require("../../aws-route53");
const aws_elasticloadbalancingv2_1 = require("aws-cdk-lib/aws-elasticloadbalancingv2");
exports.DEFAULT_ARM_IMAGE_SSM_PARAMETER = '/aws/service/canonical/ubuntu/server/jammy/stable/current/arm64/hvm/ebs-gp2/ami-id';
exports.DEFAULT_AMD64_IMAGE_SSM_PARAMETER = '/aws/service/canonical/ubuntu/server/jammy/stable/current/amd64/hvm/ebs-gp2/ami-id';
/**
 * Creates a new WordPress instance.
 */
class WordPressInstance extends constructs_1.Construct {
    resolveVpc(scope, props) {
        if (props.vpc === undefined &&
            props.vpcId === undefined &&
            props.vpcName === undefined) {
            throw new Error('One of vpc, vpcId or vpcName is required');
        }
        if (props.vpc !== undefined) {
            return props.vpc;
        }
        else if (props.vpcId !== undefined) {
            return aws_ec2_1.Vpc.fromLookup(this, 'Vpc', {
                vpcId: props.vpcId,
            });
        }
        else {
            return aws_ec2_1.Vpc.fromLookup(this, 'Vpc', {
                vpcName: props.vpcName,
            });
        }
    }
    resolveInstanceType(scope, props) {
        var _a, _b;
        return props.instanceType !== undefined
            ? props.instanceType
            : aws_ec2_1.InstanceType.of((_a = props.instanceClass) !== null && _a !== void 0 ? _a : aws_ec2_1.InstanceClass.BURSTABLE4_GRAVITON, (_b = props.instanceSize) !== null && _b !== void 0 ? _b : aws_ec2_1.InstanceSize.MICRO);
    }
    resolveSubnet(scope, props) {
        if (props.subnetId !== undefined) {
            return aws_ec2_1.Subnet.fromSubnetId(scope, 'Subnet', props.subnetId);
        }
        if (props.subnet !== undefined) {
            return props.subnet;
        }
        throw new Error('One of subnet or subnetId is required');
    }
    resolveMachineImage(instanceType) {
        return aws_ec2_1.MachineImage.fromSsmParameter(instanceType.architecture === aws_ec2_1.InstanceArchitecture.ARM_64
            ? exports.DEFAULT_ARM_IMAGE_SSM_PARAMETER
            : exports.DEFAULT_AMD64_IMAGE_SSM_PARAMETER, {
            os: aws_ec2_1.OperatingSystemType.LINUX,
        });
    }
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e;
        super(scope, id);
        for (const site of props.sites) {
            if (site.toLowerCase().startsWith('www')) {
                throw new Error('Remove "www." when specifying sites.');
            }
        }
        const stack = aws_cdk_lib_1.Stack.of(this);
        this.subnet = this.resolveSubnet(this, props);
        this.vpc = this.resolveVpc(this, props);
        const vpcSubnets = {
            subnets: [this.subnet],
        };
        if ((_a = props.createEip) !== null && _a !== void 0 ? _a : true) {
            this.eip = new aws_ec2_1.CfnEIP(this, 'PublicIpAddress', {
                tags: [
                    {
                        key: 'Name',
                        value: this.node.path,
                    },
                ],
            });
            if (props.hostPrefix !== undefined && props.hostZone !== undefined) {
                const hostName = new aws_route53_2.DomainName({
                    prefix: props.hostPrefix,
                    zone: props.hostZone,
                });
                this.eipARecord = hostName.createARecord(this, aws_route53_1.RecordTarget.fromIpAddresses(this.eip.ref), { ttl: (_b = props.hostRecordTtl) !== null && _b !== void 0 ? _b : aws_cdk_lib_1.Duration.seconds(300) });
            }
        }
        this.volume = new aws_ec2_1.Volume(this, 'DataVolume', {
            size: (_c = props.dataVolumeSize) !== null && _c !== void 0 ? _c : aws_cdk_lib_1.Size.gibibytes(10),
            volumeType: aws_autoscaling_1.EbsDeviceVolumeType.GP3,
            encrypted: true,
            encryptionKey: props.encryptionKey,
            volumeName: `${this.node.path}/Data`,
            removalPolicy: (_d = props.dataVolumeRemovalPolicy) !== null && _d !== void 0 ? _d : aws_cdk_lib_1.RemovalPolicy.RETAIN,
            availabilityZone: props.availabilityZone,
        });
        this.instanceType = this.resolveInstanceType(this, props);
        this.machineImage = this.resolveMachineImage(this.instanceType);
        const osVolumeSize = props.osVolumeSize === undefined ? 10 : props.osVolumeSize.toGibibytes();
        const userDataScript = fs.readFileSync(path.join(__dirname, 'init.sh'), 'utf-8');
        this.securityGroup = new aws_ec2_1.SecurityGroup(this, 'SecurityGroup', {
            description: 'Default security group for WordPress',
            vpc: this.vpc,
            allowAllOutbound: true,
            allowAllIpv6Outbound: true,
        });
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.anyIpv4(), aws_ec2_1.Port.tcp(2020));
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.ipv4('10.0.0.0/8'), aws_ec2_1.Port.tcp(22));
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.ipv4('172.16.0.0/12'), aws_ec2_1.Port.tcp(22));
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.ipv4('192.168.0.0/16'), aws_ec2_1.Port.tcp(22));
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.ipv6('fc00::/7'), aws_ec2_1.Port.tcp(22));
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.ipv6('fd00::/8'), aws_ec2_1.Port.tcp(22));
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.ipv6('fec0::/10'), aws_ec2_1.Port.tcp(22));
        this.securityGroup.addIngressRule(aws_ec2_1.Peer.anyIpv4(), aws_ec2_1.Port.tcp(80));
        // TODO Later on we want to whitelist cloudfront http://d7uri8nf7uskq.cloudfront.net/tools/list-cloudfront-ips
        this.asg = new aws_autoscaling_1.AutoScalingGroup(this, 'Scaling', {
            vpc: this.vpc,
            vpcSubnets,
            securityGroup: this.securityGroup,
            minCapacity: 0,
            maxCapacity: 1,
            desiredCapacity: 1,
            instanceType: this.instanceType,
            machineImage: this.machineImage,
            blockDevices: [
                {
                    deviceName: '/dev/sda1',
                    volume: aws_autoscaling_1.BlockDeviceVolume.ebs(osVolumeSize, {
                        encrypted: true,
                        deleteOnTermination: true,
                        volumeType: aws_autoscaling_1.EbsDeviceVolumeType.GP3,
                    }),
                },
            ],
            userData: aws_ec2_1.UserData.custom(userDataScript),
            updatePolicy: aws_autoscaling_1.UpdatePolicy.rollingUpdate(),
            requireImdsv2: true,
        });
        aws_cdk_lib_1.Tags.of(this.asg).add('wordpress:data-volume', this.volume.volumeId);
        aws_cdk_lib_1.Tags.of(this.asg).add('wordpress:sites', props.sites.join(' ').toLowerCase());
        this.asg.role.addManagedPolicy(aws_iam_1.ManagedPolicy.fromAwsManagedPolicyName('AmazonSSMManagedInstanceCore'));
        this.asg.addToRolePolicy(new aws_iam_1.PolicyStatement({
            effect: aws_iam_1.Effect.ALLOW,
            actions: ['ec2:DescribeTags', 'ec2:DescribeVolumes'],
            resources: ['*'],
        }));
        if (this.eip !== undefined) {
            aws_cdk_lib_1.Tags.of(this.asg).add('wordpress:eip-allocation-id', this.eip.attrAllocationId);
            this.asg.addToRolePolicy(new aws_iam_1.PolicyStatement({
                effect: aws_iam_1.Effect.ALLOW,
                actions: ['ec2:DisassociateAddress', 'ec2:AssociateAddress'],
                resources: [
                    aws_cdk_lib_1.Arn.format({
                        service: 'ec2',
                        resource: 'elastic-ip',
                        resourceName: this.eip.attrAllocationId,
                    }, stack),
                    aws_cdk_lib_1.Arn.format({
                        service: 'ec2',
                        resource: 'instance',
                        resourceName: '*',
                    }, stack),
                ],
            }));
        }
        this.volume.grantAttachVolume(this.asg);
        this.volume.grantDetachVolume(this.asg);
        if ((_e = props.createTargetGroup) !== null && _e !== void 0 ? _e : false) {
            this.targetGroup = new aws_elasticloadbalancingv2_1.ApplicationTargetGroup(this, 'TargetGroup', {
                port: 80,
                vpc: this.vpc,
                protocol: aws_elasticloadbalancingv2_1.ApplicationProtocol.HTTP,
                protocolVersion: aws_elasticloadbalancingv2_1.ApplicationProtocolVersion.HTTP1,
                targets: [this.asg],
                healthCheck: {
                    protocol: aws_elasticloadbalancingv2_1.Protocol.HTTP,
                    healthyHttpCodes: '200-499',
                    healthyThresholdCount: 2,
                    unhealthyThresholdCount: 2,
                },
            });
        }
    }
    /**
     * Convenience method to add the created target group as a default target for a load balancer listener.
     *
     * @param listener - the listener to attach the target group to
     */
    addListenerTarget(listener) {
        if (!this.targetGroup) {
            throw new Error('No target group exists');
        }
        listener.addTargetGroups('Default', {
            targetGroups: [this.targetGroup],
        });
    }
    /**
     * Convenience method to add a rule to a load balancer listener for the created target group.
     *
     * @param listener - this listener to attach the rule to
     * @param priority - the priority of the rule
     * @param conditions - the listener conditions to match
     */
    addListenerRule(listener, priority, conditions) {
        if (!this.targetGroup) {
            throw new Error('No target group exists');
        }
        return new aws_elasticloadbalancingv2_1.ApplicationListenerRule(this, `ListenerRule${priority}`, {
            listener,
            priority,
            targetGroups: [this.targetGroup],
            conditions,
        });
    }
}
exports.WordPressInstance = WordPressInstance;
//# sourceMappingURL=word-press-instance.js.map