"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainName = void 0;
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const weighted_a_record_1 = require("./weighted-a-record");
const latency_a_record_1 = require("./latency-a-record");
const aws_certificatemanager_1 = require("aws-cdk-lib/aws-certificatemanager");
const helpers_1 = require("../../helpers");
/**
 * Utility class for holding domain name information and
 * doing useful things with it.
 */
class DomainName {
    /**
     * Creates a new DomainName.
     *
     * @param props the properties of the domain name
     */
    constructor(props) {
        var _a, _b;
        this.prefix = (_a = props.prefix) !== null && _a !== void 0 ? _a : '';
        if (typeof props.zone === 'string') {
            this.zone = props.zone;
        }
        else {
            this.hostedZone = props.zone;
            this.zone = this.hostedZone.zoneName;
        }
        this.privateZone = (_b = props.privateZone) !== null && _b !== void 0 ? _b : false;
        this.vpcId = props.vpcId;
    }
    /**
     * Returns the prefix for this domain name.
     */
    getPrefix() {
        return this.prefix;
    }
    /**
     * Returns true if the zone is private. False if otherwise.
     */
    inPrivateZone() {
        return this.privateZone;
    }
    /**
     * Returns the vpc ID for this zone or undefined if one does not exist
     */
    getVpcId() {
        return this.vpcId;
    }
    /**
     * Returns true if the props match the domain name. False if otherwise.
     *
     * @param props the props to compare
     */
    propsMatch(props) {
        var _a, _b;
        const propZoneStr = typeof props.zone === 'string' ? props.zone : props.zone.zoneName;
        return (this.prefix === ((_a = props.prefix) !== null && _a !== void 0 ? _a : '') &&
            this.zone === propZoneStr &&
            this.privateZone === ((_b = props.privateZone) !== null && _b !== void 0 ? _b : false) &&
            this.vpcId === props.vpcId);
    }
    /**
     * Returns the string version of this domain name.
     */
    toString() {
        return (this.prefix === '' ? '' : this.prefix + '.') + this.zone;
    }
    /**
     * Returns a friendly identifier for this domain name. This function replaces wildcards with _ and periods with -
     */
    toIdentifier() {
        return helpers_1.StringHelper.toPascalCase(this.toString()
            .toLowerCase()
            .replace(/\*/g, 'wildcard')
            .replace(/\./g, '-'));
    }
    /**
     * Returns the zone associated with this domain name.
     */
    getZone() {
        return this.zone;
    }
    /**
     * Returns the route53 hosted zone associated with this domain name.
     * This method is safe to call repeatedly, the lookup will only be done once.
     *
     * @param scope the scope to use if a lookup is required
     * @param id an optional ID if a lookup is required; one is generated if not provided
     */
    getHostedZone(scope, id) {
        if (this.hostedZone === undefined) {
            this.hostedZone = aws_route53_1.HostedZone.fromLookup(scope, id !== null && id !== void 0 ? id : `${this.toIdentifier()}-zone`, {
                domainName: this.zone,
                privateZone: this.privateZone,
                vpcId: this.vpcId,
            });
        }
        return this.hostedZone;
    }
    scrubIdentifier(identifier) {
        return /^\d/.test(identifier) ? 'x' + identifier : identifier;
    }
    /**
     * Creates a Route53 ARecord for this domain name.
     *
     * @param scope the scope to create the record in
     * @param target the target of the record
     * @param options additional options for creating the record
     */
    createARecord(scope, target, options) {
        var _a;
        return new aws_route53_1.ARecord(scope, (_a = options === null || options === void 0 ? void 0 : options.id) !== null && _a !== void 0 ? _a : `${this.scrubIdentifier(this.toIdentifier())}ARecord`, {
            zone: this.getHostedZone(scope),
            recordName: this.toString(),
            target,
            ttl: options === null || options === void 0 ? void 0 : options.ttl,
            comment: options === null || options === void 0 ? void 0 : options.comment,
            deleteExisting: options === null || options === void 0 ? void 0 : options.deleteExisting,
        });
    }
    /**
     * Creates a weighted Route53 record for this domain name.
     *
     * @param scope the scope to create the record in
     * @param target the target of the record
     * @param weight the initial weight
     * @param options additional options for creating the record
     */
    createWeightedARecord(scope, target, weight, options) {
        var _a;
        return new weighted_a_record_1.WeightedARecord(scope, (_a = options === null || options === void 0 ? void 0 : options.id) !== null && _a !== void 0 ? _a : `${this.scrubIdentifier(this.toIdentifier())}ARecord`, {
            zone: this.getHostedZone(scope),
            recordName: this.toString(),
            target,
            weight,
            ttl: options === null || options === void 0 ? void 0 : options.ttl,
            comment: options === null || options === void 0 ? void 0 : options.comment,
            deleteExisting: options === null || options === void 0 ? void 0 : options.deleteExisting,
        });
    }
    /**
     * Creates a latency Route53 record for this domain name.
     *
     * @param scope the scope to create the record in
     * @param target the target of the record
     * @param options additional options for creating the record
     */
    createLatencyARecord(scope, target, options) {
        var _a;
        return new latency_a_record_1.LatencyARecord(scope, (_a = options === null || options === void 0 ? void 0 : options.id) !== null && _a !== void 0 ? _a : `${this.scrubIdentifier(this.toIdentifier())}ARecord`, {
            zone: this.getHostedZone(scope),
            recordName: this.toString(),
            target,
            ttl: options === null || options === void 0 ? void 0 : options.ttl,
            comment: options === null || options === void 0 ? void 0 : options.comment,
            deleteExisting: options === null || options === void 0 ? void 0 : options.deleteExisting,
        });
    }
    /**
     * Creates an ACM certificate for the domain name.
     *
     * @param scope the scope to create the record in
     * @param opts additional options
     */
    createCertificate(scope, opts) {
        var _a;
        return new aws_certificatemanager_1.Certificate(scope, (_a = opts === null || opts === void 0 ? void 0 : opts.id) !== null && _a !== void 0 ? _a : `${this.toIdentifier()}Certificate`, {
            domainName: this.toString(),
            validation: aws_certificatemanager_1.CertificateValidation.fromDns(this.getHostedZone(scope)),
            subjectAlternativeNames: opts === null || opts === void 0 ? void 0 : opts.subjectAlternativeNames,
        });
    }
    /**
     * Converts an array of DomainNameProps to DomainName. This function will return an empty array
     * if domainNameProps is undefined.
     *
     * @param domainNameProps the DomainNameProps objects to convert
     */
    static fromProps(domainNameProps) {
        return domainNameProps === undefined
            ? []
            : domainNameProps.map(p => new DomainName(p));
    }
    /**
     * Creates an instance of DomainName from a fully qualified domain name and a zone.
     *
     * @param fqdn the fully qualified domain name
     * @param zone the zone
     */
    static fromFqdn(fqdn, zone, privateZone, vpcId) {
        const prefix = fqdn
            .replace(typeof zone === 'string' ? zone : zone.zoneName, '')
            .replace(/\.$/, '');
        return new DomainName({
            prefix,
            zone,
            privateZone,
            vpcId,
        });
    }
    /**
     * Converts an array of DomainName objects to an array of strings. This function will return an
     * empty array if domainNames is undefined.
     *
     * @param domainNames the DomainName objects to convert
     */
    static toStrings(domainNames) {
        return domainNames === undefined ? [] : domainNames.map(d => d.toString());
    }
    /**
     * Converts an array of DomainNameProps to an array of strings. This function will
     * return an empty array if domainNameProps is undefined.
     *
     * @param domainNameProps the DomainNameProps objects to convert
     */
    static toStringsFromProps(domainNameProps) {
        return domainNameProps === undefined
            ? []
            : DomainName.toStrings(DomainName.fromProps(domainNameProps));
    }
    /**
     * Converts an array of DomainName objects to a map where the key is the domain name string and the value
     * is an IHostedZone. This method will return an empty map if domainNames is undefined. This function
     * is useful when used in conjunction with functions like CertificateValidation.fromDnsMultiZone.
     *
     * @param scope the scope used if a zone lookup is required
     * @param domainNames the DomainName objects to convert
     */
    static toZoneMap(scope, domainNames) {
        const map = {};
        if (domainNames !== undefined) {
            domainNames.forEach(d => {
                map[d.toString()] = d.getHostedZone(scope);
            });
        }
        return map;
    }
    /**
     * Converts an array of DomainNameProps objects to a map where the key is the domain name string and the
     * value is an IHostedZone. This method will return an empty map if domainNameProps is undefined. This
     * function is useful when used in conjunction with functions like CertificateValidation.fromDnsMultiZone.
     *
     * @param scope the scope used if a zone lookup is required
     * @param domainNameProps the DomainNameProps objects to convert
     */
    static toZoneMapFromProps(scope, domainNameProps) {
        return DomainName.toZoneMap(scope, DomainName.fromProps(domainNameProps));
    }
    /**
     * Finds the domain name matching the given properties in an array of DomainName objects.
     *
     * @param props the properties to compare
     * @param domainNames the domain names to search
     * @return the matching domain name or undefined
     */
    static findDomainName(props, domainNames) {
        for (const domainName of domainNames !== null && domainNames !== void 0 ? domainNames : []) {
            if (domainName.propsMatch(props)) {
                return domainName;
            }
        }
        return undefined;
    }
    /**
     * Create a certificate from an array of DomainName objects.
     *
     * @param scope the scope to use
     * @param id the identifier to use in the scope for the certificate
     * @param domainNames the domain names to use in the certificate
     */
    static createCertificate(scope, id, domainNames) {
        return new aws_certificatemanager_1.Certificate(scope, id, {
            domainName: domainNames[0].toString(),
            subjectAlternativeNames: domainNames
                .slice(1)
                .map(name => name.toString()),
            validation: aws_certificatemanager_1.CertificateValidation.fromDnsMultiZone(DomainName.toZoneMap(scope, domainNames)),
        });
    }
}
exports.DomainName = DomainName;
//# sourceMappingURL=domain-name.js.map