"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudFrontBucket = exports.OPEN_CORS_RULE = void 0;
const aws_s3_1 = require("aws-cdk-lib/aws-s3");
const aws_cloudfront_1 = require("aws-cdk-lib/aws-cloudfront");
const aws_s3_deployment_1 = require("aws-cdk-lib/aws-s3-deployment");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
const aws_cloudfront_origins_1 = require("aws-cdk-lib/aws-cloudfront-origins");
exports.OPEN_CORS_RULE = {
    allowedMethods: [
        aws_s3_1.HttpMethods.GET,
        aws_s3_1.HttpMethods.HEAD,
        aws_s3_1.HttpMethods.DELETE,
        aws_s3_1.HttpMethods.PUT,
        aws_s3_1.HttpMethods.POST,
    ],
    allowedOrigins: ['*'],
    allowedHeaders: ['*'],
    exposedHeaders: ['ETag'],
    maxAge: 3000,
};
/**
 * Simple Construct for creating buckets that will be accessed directly by CloudFront as an Origin.
 */
class CloudFrontBucket extends aws_cdk_1.ExtendedConstruct {
    nextDeployCount() {
        const current = this.deployCount++;
        return current === 0 ? '' : `${current}`;
    }
    constructor(scope, id, props) {
        var _a, _b, _c, _d;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props === null || props === void 0 ? void 0 : props.standardTags, truemark_1.LibStandardTags),
        });
        this.deployCount = 0;
        const removalPolicy = (_a = props === null || props === void 0 ? void 0 : props.removalPolicy) !== null && _a !== void 0 ? _a : aws_cdk_lib_1.RemovalPolicy.RETAIN;
        const autoDeleteObjects = ((_b = props === null || props === void 0 ? void 0 : props.autoDeleteObjects) !== null && _b !== void 0 ? _b : false) &&
            removalPolicy === aws_cdk_lib_1.RemovalPolicy.DESTROY;
        this.bucket = new aws_s3_1.Bucket(this, 'Default', {
            encryption: aws_s3_1.BucketEncryption.S3_MANAGED,
            blockPublicAccess: aws_s3_1.BlockPublicAccess.BLOCK_ALL,
            removalPolicy,
            autoDeleteObjects,
            versioned: (_c = props === null || props === void 0 ? void 0 : props.versioned) !== null && _c !== void 0 ? _c : false,
            transferAcceleration: (_d = props === null || props === void 0 ? void 0 : props.transferAcceleration) !== null && _d !== void 0 ? _d : false,
            bucketName: props === null || props === void 0 ? void 0 : props.bucketName,
            cors: props === null || props === void 0 ? void 0 : props.cors,
        });
        this.bucketName = this.bucket.bucketName;
        this.bucketArn = this.bucket.bucketArn;
        this.originAccessIdentity = new aws_cloudfront_1.OriginAccessIdentity(this, 'Access', {
            comment: `S3 bucket ${this.bucket.bucketName}`,
        });
        this.originAccessIdentityId =
            this.originAccessIdentity.originAccessIdentityId;
        this.bucket.grantRead(this.originAccessIdentity);
    }
    /**
     * Helper method to deploy local assets to the created bucket. Ths function assumes
     * CloudFront invalidation requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param paths the paths to the local assets
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune true to prune old files; default is false
     */
    deployPaths(paths, maxAge, sMaxAge, prune) {
        return new aws_s3_deployment_1.BucketDeployment(this, `Deploy${this.nextDeployCount()}`, {
            sources: paths.map(path => aws_s3_deployment_1.Source.asset(path)),
            destinationBucket: this.bucket,
            prune: prune !== null && prune !== void 0 ? prune : false,
            cacheControl: [
                aws_s3_deployment_1.CacheControl.setPublic(),
                aws_s3_deployment_1.CacheControl.maxAge(maxAge !== null && maxAge !== void 0 ? maxAge : aws_cdk_lib_1.Duration.minutes(15)),
                aws_s3_deployment_1.CacheControl.sMaxAge(sMaxAge !== null && sMaxAge !== void 0 ? sMaxAge : aws_cdk_lib_1.Duration.days(7)),
            ],
        });
    }
    /**
     * Helper method to deploy local assets to the created bucket. Ths function assumes
     * CloudFront invalidation requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param path the path to the local assets
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune true to prune old files; default is false
     */
    deployPath(path, maxAge, sMaxAge, prune) {
        return this.deployPaths([path], maxAge, sMaxAge, prune);
    }
    /**
     * Helper method to assets to the created bucket. This function assumes CloudFront invalidation
     * requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param sources the sources to deploy
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune true to prune old files; default is false
     */
    deploySources(sources, maxAge, sMaxAge, prune) {
        return new aws_s3_deployment_1.BucketDeployment(this, `Deploy${this.nextDeployCount()}`, {
            sources: sources,
            destinationBucket: this.bucket,
            prune: prune !== null && prune !== void 0 ? prune : false,
            cacheControl: [
                aws_s3_deployment_1.CacheControl.setPublic(),
                aws_s3_deployment_1.CacheControl.maxAge(maxAge !== null && maxAge !== void 0 ? maxAge : aws_cdk_lib_1.Duration.minutes(15)),
                aws_s3_deployment_1.CacheControl.sMaxAge(sMaxAge !== null && sMaxAge !== void 0 ? sMaxAge : aws_cdk_lib_1.Duration.days(7)),
            ],
        });
    }
    /**
     * Helper method to assets to the created bucket. This function assumes CloudFront invalidation
     * requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param source the source to deploy
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune true to prune old files; default is false
     */
    deploySource(source, maxAge, sMaxAge, prune) {
        return this.deploySources([source], maxAge, sMaxAge, prune);
    }
    /**
     * Helper method to return a CloudFront Origin for this bucket.
     */
    toOrigin() {
        return new aws_cloudfront_origins_1.S3Origin(this.bucket, {
            originAccessIdentity: this.originAccessIdentity,
        });
    }
    /**
     * Grant read permissions for this bucket and it's contents to an IAM
     * principal (Role/Group/User).
     *
     * If encryption is used, permission to use the key to decrypt the contents
     * of the bucket will also be granted to the same principal.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    grantRead(identity, objectsKeyPattern) {
        return this.bucket.grantRead(identity, objectsKeyPattern);
    }
    /**
     * Grant write permissions to this bucket to an IAM principal.
     *
     * If encryption is used, permission to use the key to encrypt the contents
     * of written files will also be granted to the same principal.
     *
     * Before CDK version 1.85.0, this method granted the `s3:PutObject*` permission that included `s3:PutObjectAcl`,
     * which could be used to grant read/write object access to IAM principals in other accounts.
     * If you want to get rid of that behavior, update your CDK version to 1.85.0 or later,
     * and make sure the `@aws-cdk/aws-s3:grantWriteWithoutAcl` feature flag is set to `true`
     * in the `context` key of your cdk.json file.
     * If you've already updated, but still need the principal to have permissions to modify the ACLs,
     * use the `grantPutAcl` method.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     * @param allowedActionPatterns Restrict the permissions to certain list of action patterns
     */
    grantWrite(identity, objectsKeyPattern, allowedActionPatterns) {
        return this.bucket.grantWrite(identity, objectsKeyPattern, allowedActionPatterns);
    }
    /**
     * Grants s3:PutObject* and s3:Abort* permissions for this bucket to an IAM principal.
     *
     * If encryption is used, permission to use the key to encrypt the contents
     * of written files will also be granted to the same principal.
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    grantPut(identity, objectsKeyPattern) {
        return this.bucket.grantPut(identity, objectsKeyPattern);
    }
    /**
     * Grant the given IAM identity permissions to modify the ACLs of objects in the given Bucket.
     *
     * If your application has the '@aws-cdk/aws-s3:grantWriteWithoutAcl' feature flag set,
     * calling `grantWrite` or `grantReadWrite` no longer grants permissions to modify the ACLs of the objects;
     * in this case, if you need to modify object ACLs, call this method explicitly.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    grantPutAcl(identity, objectsKeyPattern) {
        return this.bucket.grantPutAcl(identity, objectsKeyPattern);
    }
    /**
     * Grants s3:DeleteObject* permission to an IAM principal for objects
     * in this bucket.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    grantDelete(identity, objectsKeyPattern) {
        return this.bucket.grantDelete(identity, objectsKeyPattern);
    }
    /**
     * Grants read/write permissions for this bucket and it's contents to an IAM
     * principal (Role/Group/User).
     *
     * If an encryption key is used, permission to use the key for
     * encrypt/decrypt will also be granted.
     *
     * Before CDK version 1.85.0, this method granted the `s3:PutObject*` permission that included `s3:PutObjectAcl`,
     * which could be used to grant read/write object access to IAM principals in other accounts.
     * If you want to get rid of that behavior, update your CDK version to 1.85.0 or later,
     * and make sure the `@aws-cdk/aws-s3:grantWriteWithoutAcl` feature flag is set to `true`
     * in the `context` key of your cdk.json file.
     * If you've already updated, but still need the principal to have permissions to modify the ACLs,
     * use the `grantPutAcl` method.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    grantReadWrite(identity, objectsKeyPattern) {
        return this.bucket.grantReadWrite(identity, objectsKeyPattern);
    }
    /**
     * Adds a statement to the resource policy for a principal (i.e.
     * account/role/service) to perform actions on this bucket and/or its
     * contents. Use `bucketArn` and `arnForObjects(keys)` to obtain ARNs for
     * this bucket or objects.
     *
     * Note that the policy statement may or may not be added to the policy.
     * For example, when an `IBucket` is created from an existing bucket,
     * it's not possible to tell whether the bucket already has a policy
     * attached, let alone to re-use that policy to add more statements to it.
     * So it's safest to do nothing in these cases.
     *
     * @param permission the policy statement to be added to the bucket's
     * policy.
     * @returns metadata about the execution of this method. If the policy
     * was not added, the value of `statementAdded` will be `false`. You
     * should always check this value to make sure that the operation was
     * actually carried out. Otherwise, synthesis and deploy will terminate
     * silently, which may be confusing.
     */
    addToResourcePolicy(permission) {
        return this.bucket.addToResourcePolicy(permission);
    }
}
exports.CloudFrontBucket = CloudFrontBucket;
//# sourceMappingURL=cloud-front-bucket.js.map