"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebsiteBucket = void 0;
const constructs_1 = require("constructs");
const aws_s3_1 = require("aws-cdk-lib/aws-s3");
const aws_route53_1 = require("../../aws-route53");
const aws_route53_2 = require("aws-cdk-lib/aws-route53");
const aws_route53_targets_1 = require("aws-cdk-lib/aws-route53-targets");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_s3_deployment_1 = require("aws-cdk-lib/aws-s3-deployment");
/**
 * Simple Construct for creating buckets that will be accessed directly as a website.
 */
class WebsiteBucket extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        super(scope, id);
        const removalPolicy = (_a = props === null || props === void 0 ? void 0 : props.removalPolicy) !== null && _a !== void 0 ? _a : aws_cdk_lib_1.RemovalPolicy.RETAIN;
        const autoDeleteObjects = ((_b = props === null || props === void 0 ? void 0 : props.autoDeleteObjects) !== null && _b !== void 0 ? _b : false) &&
            removalPolicy === aws_cdk_lib_1.RemovalPolicy.DESTROY;
        const domainName = (props === null || props === void 0 ? void 0 : props.domainName) === undefined
            ? undefined
            : new aws_route53_1.DomainName({
                prefix: props.domainName.prefix,
                zone: props.domainName.zone,
            });
        this.bucket = new aws_s3_1.Bucket(this, 'Default', {
            bucketName: domainName === null || domainName === void 0 ? void 0 : domainName.toString(),
            encryption: aws_s3_1.BucketEncryption.S3_MANAGED,
            publicReadAccess: true,
            websiteIndexDocument: (_c = props === null || props === void 0 ? void 0 : props.websiteIndexDocument) !== null && _c !== void 0 ? _c : 'index.html',
            websiteErrorDocument: (_d = props === null || props === void 0 ? void 0 : props.websiteErrorDocument) !== null && _d !== void 0 ? _d : 'error.html',
            websiteRedirect: props === null || props === void 0 ? void 0 : props.websiteRedirect,
            websiteRoutingRules: props === null || props === void 0 ? void 0 : props.websiteRoutingRules,
            removalPolicy,
            autoDeleteObjects,
        });
        this.bucketName = this.bucket.bucketName;
        this.bucketArn = this.bucket.bucketArn;
        this.bucketWebsiteUrl = this.bucket.bucketWebsiteUrl;
        this.bucketWebsiteDomainName = this.bucket.bucketWebsiteDomainName;
        if (domainName !== undefined && ((_f = (_e = props === null || props === void 0 ? void 0 : props.domainName) === null || _e === void 0 ? void 0 : _e.create) !== null && _f !== void 0 ? _f : true)) {
            const target = aws_route53_2.RecordTarget.fromAlias(new aws_route53_targets_1.BucketWebsiteTarget(this.bucket));
            // TODO Evaluate
            if (((_g = props === null || props === void 0 ? void 0 : props.domainName) === null || _g === void 0 ? void 0 : _g.latency) !== undefined) {
                this.record = domainName.createLatencyARecord(this, target);
            }
            else if (((_h = props === null || props === void 0 ? void 0 : props.domainName) === null || _h === void 0 ? void 0 : _h.weight) !== undefined) {
                this.record = domainName.createWeightedARecord(this, target, props.domainName.weight);
            }
            else {
                this.record = domainName.createARecord(this, target);
            }
        }
    }
    /**
     * Helper method to deploy local assets to the created bucket. Ths function assumes
     * CloudFront invalidation requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param path the path to the local assets
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune
     */
    deploy(path, maxAge, sMaxAge, prune) {
        return new aws_s3_deployment_1.BucketDeployment(this, 'Deploy', {
            sources: [aws_s3_deployment_1.Source.asset(path)],
            destinationBucket: this.bucket,
            prune: prune !== null && prune !== void 0 ? prune : false,
            memoryLimit: 512,
            cacheControl: [
                aws_s3_deployment_1.CacheControl.setPublic(),
                aws_s3_deployment_1.CacheControl.maxAge(maxAge !== null && maxAge !== void 0 ? maxAge : aws_cdk_lib_1.Duration.minutes(15)),
                aws_s3_deployment_1.CacheControl.sMaxAge(sMaxAge !== null && sMaxAge !== void 0 ? sMaxAge : aws_cdk_lib_1.Duration.days(7)),
            ],
        });
    }
    /**
     * Grant read permissions for this bucket and it's contents to an IAM
     * principal (Role/Group/User).
     *
     * If encryption is used, permission to use the key to decrypt the contents
     * of the bucket will also be granted to the same principal.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    // eslint-disable-next-line  @typescript-eslint/no-explicit-any
    grantRead(identity, objectsKeyPattern) {
        return this.bucket.grantRead(identity, objectsKeyPattern);
    }
    /**
     * Grant write permissions to this bucket to an IAM principal.
     *
     * If encryption is used, permission to use the key to encrypt the contents
     * of written files will also be granted to the same principal.
     *
     * Before CDK version 1.85.0, this method granted the `s3:PutObject*` permission that included `s3:PutObjectAcl`,
     * which could be used to grant read/write object access to IAM principals in other accounts.
     * If you want to get rid of that behavior, update your CDK version to 1.85.0 or later,
     * and make sure the `@aws-cdk/aws-s3:grantWriteWithoutAcl` feature flag is set to `true`
     * in the `context` key of your cdk.json file.
     * If you've already updated, but still need the principal to have permissions to modify the ACLs,
     * use the `grantPutAcl` method.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     * @param allowedActionPatterns Restrict the permissions to certain list of action patterns
     */
    grantWrite(identity, 
    // eslint-disable-next-line  @typescript-eslint/no-explicit-any
    objectsKeyPattern, allowedActionPatterns) {
        return this.bucket.grantWrite(identity, objectsKeyPattern, allowedActionPatterns);
    }
    /**
     * Grants s3:PutObject* and s3:Abort* permissions for this bucket to an IAM principal.
     *
     * If encryption is used, permission to use the key to encrypt the contents
     * of written files will also be granted to the same principal.
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    // eslint-disable-next-line  @typescript-eslint/no-explicit-any
    grantPut(identity, objectsKeyPattern) {
        return this.bucket.grantPut(identity, objectsKeyPattern);
    }
    /**
     * Grant the given IAM identity permissions to modify the ACLs of objects in the given Bucket.
     *
     * If your application has the '@aws-cdk/aws-s3:grantWriteWithoutAcl' feature flag set,
     * calling `grantWrite` or `grantReadWrite` no longer grants permissions to modify the ACLs of the objects;
     * in this case, if you need to modify object ACLs, call this method explicitly.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    grantPutAcl(identity, objectsKeyPattern) {
        return this.bucket.grantPutAcl(identity, objectsKeyPattern);
    }
    /**
     * Grants s3:DeleteObject* permission to an IAM principal for objects
     * in this bucket.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    // eslint-disable-next-line  @typescript-eslint/no-explicit-any
    grantDelete(identity, objectsKeyPattern) {
        return this.bucket.grantDelete(identity, objectsKeyPattern);
    }
    /**
     * Grants read/write permissions for this bucket and it's contents to an IAM
     * principal (Role/Group/User).
     *
     * If an encryption key is used, permission to use the key for
     * encrypt/decrypt will also be granted.
     *
     * Before CDK version 1.85.0, this method granted the `s3:PutObject*` permission that included `s3:PutObjectAcl`,
     * which could be used to grant read/write object access to IAM principals in other accounts.
     * If you want to get rid of that behavior, update your CDK version to 1.85.0 or later,
     * and make sure the `@aws-cdk/aws-s3:grantWriteWithoutAcl` feature flag is set to `true`
     * in the `context` key of your cdk.json file.
     * If you've already updated, but still need the principal to have permissions to modify the ACLs,
     * use the `grantPutAcl` method.
     *
     * @param identity The principal
     * @param objectsKeyPattern Restrict the permission to a certain key pattern (default '*')
     */
    // eslint-disable-next-line  @typescript-eslint/no-explicit-any
    grantReadWrite(identity, objectsKeyPattern) {
        return this.bucket.grantReadWrite(identity, objectsKeyPattern);
    }
    /**
     * Adds a statement to the resource policy for a principal (i.e.
     * account/role/service) to perform actions on this bucket and/or its
     * contents. Use `bucketArn` and `arnForObjects(keys)` to obtain ARNs for
     * this bucket or objects.
     *
     * Note that the policy statement may or may not be added to the policy.
     * For example, when an `IBucket` is created from an existing bucket,
     * it's not possible to tell whether the bucket already has a policy
     * attached, let alone to re-use that policy to add more statements to it.
     * So it's safest to do nothing in these cases.
     *
     * @param permission the policy statement to be added to the bucket's
     * policy.
     * @returns metadata about the execution of this method. If the policy
     * was not added, the value of `statementAdded` will be `false`. You
     * should always check this value to make sure that the operation was
     * actually carried out. Otherwise, synthesis and deploy will terminate
     * silently, which may be confusing.
     */
    addToResourcePolicy(permission) {
        return this.bucket.addToResourcePolicy(permission);
    }
}
exports.WebsiteBucket = WebsiteBucket;
//# sourceMappingURL=website-bucket.js.map